@@ -40,28 +40,30 @@
  *   chunk reading
  */
 
+#include "st_i.h"
+
 #include <math.h>
 #include <time.h>      /* for time stamping comments */
 #include <stdlib.h>
 #include <string.h>
 #include <stdio.h>
-
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>	/* For SEEK_* defines if not found in stdio */
 #endif
 
-#include "st.h"
-
 /* Private data used by writer */
 typedef struct aiffpriv {
-	ULONG nsamples;	/* number of 1-channel samples read or written */
-					/*Decrements for read increments for write */
-    LONG dataStart;  /* need to for seeking */
+    st_size_t nsamples;  /* number of 1-channel samples read or written */
+			 /* Decrements for read increments for write */
+    st_size_t dataStart; /* need to for seeking */
 } *aiff_t;
 
 /* forward declarations */
 static double read_ieee_extended(ft_t);
-static int aiffwriteheader(ft_t, LONG);
+static int aiffwriteheader(ft_t, st_size_t);
 static void write_ieee_extended(ft_t, double);
 static double ConvertFromIeeeExtended(unsigned char*);
 static void ConvertToIeeeExtended(double, char *);
@@ -69,9 +71,7 @@ static int textChunk(char **text, char *chunkDescription, ft_t ft);
 static int commentChunk(char **text, char *chunkDescription, ft_t ft);
 static void reportInstrument(ft_t ft);
 
-int st_aiffseek(ft,offset) 
-ft_t ft;
-LONG offset;
+int st_aiffseek(ft_t ft, st_size_t offset) 
 {
 	aiff_t aiff = (aiff_t ) ft->priv;
 
@@ -83,23 +83,22 @@ LONG offset;
 	return(ft->st_errno);
 }
 
-int st_aiffstartread(ft) 
-ft_t ft;
+int st_aiffstartread(ft_t ft) 
 {
 	aiff_t aiff = (aiff_t ) ft->priv;
 	char buf[5];
-	ULONG totalsize;
-	LONG chunksize;
+	uint32_t totalsize;
+	uint32_t chunksize;
 	unsigned short channels = 0;
-	ULONG frames;
+	uint32_t frames;
 	unsigned short bits = 0;
 	double rate = 0.0;
-	ULONG offset = 0;
-	ULONG blocksize = 0;
+	uint32_t offset = 0;
+	uint32_t blocksize = 0;
 	int foundcomm = 0, foundmark = 0, foundinstr = 0;
 	struct mark {
 		unsigned short id;
-		ULONG position;
+		uint32_t position;
 		char name[40]; 
 	} marks[32];
 	unsigned short looptype;
@@ -107,12 +106,14 @@ ft_t ft;
 	unsigned short nmarks = 0;
 	unsigned short sustainLoopBegin = 0, sustainLoopEnd = 0,
 	     	       releaseLoopBegin = 0, releaseLoopEnd = 0;
-	LONG seekto = 0L, ssndsize = 0L;
+	st_size_t seekto = 0L, ssndsize = 0L;
 	char *author;
 	char *copyright;
 	char *nametext;
 
-	ULONG trash;
+	uint8_t trash8;
+	uint16_t trash16;
+	uint32_t trash32;
 
 	int rc;
 
@@ -171,7 +172,7 @@ ft_t ft;
 			    }
 			}
 			while(chunksize-- > 0)
-			    st_readb(ft, (unsigned char *)&trash);
+			    st_readb(ft, (unsigned char *)&trash8);
 			foundcomm = 1;
 		}
 		else if (strncmp(buf, "SSND", 4) == 0) {
@@ -216,27 +217,27 @@ ft_t ft;
 				marks[i].name[j] = 0;
 				if ((len & 1) == 0) {
 					chunksize--;
-					st_readb(ft, (unsigned char *)&trash);
+					st_readb(ft, (unsigned char *)&trash8);
 				}
 			}
 			/* HA HA!  Sound Designer (and others) makes */
 			/* bogus files. It spits out bogus chunksize */
 			/* for MARK field */
 			while(chunksize-- > 0)
-			    st_readb(ft, (unsigned char *)&trash);
+			    st_readb(ft, (unsigned char *)&trash8);
 		}
 		else if (strncmp(buf, "INST", 4) == 0) {
 			/* INST chunk */
 			st_readdw(ft, &chunksize);
 			st_readb(ft, &(ft->instr.MIDInote));
-			st_readb(ft, (unsigned char *)&trash);
+			st_readb(ft, (unsigned char *)&trash8);
 			st_readb(ft, &(ft->instr.MIDIlow));
 			st_readb(ft, &(ft->instr.MIDIhi));
 			/* Low  velocity */
-			st_readb(ft, (unsigned char *)&trash);
+			st_readb(ft, (unsigned char *)&trash8);
 			/* Hi  velocity */
-			st_readb(ft, (unsigned char *)&trash);
-			st_readw(ft, (unsigned short *)&trash);	/* gain */
+			st_readb(ft, (unsigned char *)&trash8);
+			st_readw(ft, (unsigned short *)&trash16);/* gain */
 			st_readw(ft, &looptype); /* sustain loop */
 			ft->loops[0].type = looptype;
 			st_readw(ft, &sustainLoopBegin); /* begin marker */
@@ -251,15 +252,15 @@ ft_t ft;
 		else if (strncmp(buf, "APPL", 4) == 0) {
 			st_readdw(ft, &chunksize);
 			while(chunksize-- > 0)
-			    st_readb(ft, (unsigned char *)&trash);
+			    st_readb(ft, (unsigned char *)&trash8);
 		}
 		else if (strncmp(buf, "ALCH", 4) == 0) {
 			/* I think this is bogus and gets grabbed by APPL */
 			/* INST chunk */
-			st_readdw(ft, &trash);		/* ENVS - jeez! */
+			st_readdw(ft, &trash32);		/* ENVS - jeez! */
 			st_readdw(ft, &chunksize);
 			while(chunksize-- > 0)
-			    st_readb(ft, (unsigned char *)&trash);
+			    st_readb(ft, (unsigned char *)&trash8);
 		}
 		else if (strncmp(buf, "ANNO", 4) == 0) {
 			rc = textChunk(&(ft->comment), "Annotation:", ft);
@@ -323,7 +324,7 @@ ft_t ft;
 			/* Skip the chunk using st_readb() so we may read
 			   from a pipe */
 			while (chunksize-- > 0) {
-			    if (st_readb(ft, (unsigned char *)&trash) == ST_EOF)
+			    if (st_readb(ft, (unsigned char *)&trash8) == ST_EOF)
 					break;
 			}
 		}
@@ -351,8 +352,8 @@ ft_t ft;
 		st_fail_errno(ft,ST_EHDR,"AIFF header specifies nonzero blocksize?!?!");
 		return(ST_EOF);
 	}
-	while ((LONG) (--offset) >= 0) {
-		if (st_readb(ft, (unsigned char *)&trash) == ST_EOF)
+	while (offset-- > 0) {
+		if (st_readb(ft, (unsigned char *)&trash8) == ST_EOF)
 		{
 			st_fail_errno(ft,errno,"unexpected EOF while skipping AIFF offset");
 			return(ST_EOF);
@@ -462,8 +463,7 @@ ft_t ft;
 }
 
 /* print out the MIDI key allocations, loop points, directions etc */
-static void reportInstrument(ft)
-ft_t ft;
+static void reportInstrument(ft_t ft)
 {
   int loopNum;
 
@@ -489,12 +489,9 @@ ft_t ft;
 }
 
 /* Process a text chunk, allocate memory, display it if verbose and return */
-static int textChunk(text, chunkDescription, ft) 
-char **text;
-char *chunkDescription;
-ft_t ft;
+static int textChunk(char **text, char *chunkDescription, ft_t ft) 
 {
-  LONG chunksize;
+  uint32_t chunksize;
   st_readdw(ft, &chunksize);
   /* allocate enough memory to hold the text including a terminating \0 */
   *text = (char *) malloc((size_t) chunksize + 1);
@@ -526,14 +523,11 @@ ft_t ft;
 /* Comment lengths are words, not double words, and we can have several, so
    we use a special function, not textChunk().;
  */
-static int commentChunk(text, chunkDescription, ft)
-char **text;
-char *chunkDescription;
-ft_t ft;
+static int commentChunk(char **text, char *chunkDescription, ft_t ft)
 {
-  LONG chunksize;
+  uint32_t chunksize;
   unsigned short numComments;
-  LONG timeStamp;
+  uint32_t timeStamp;
   unsigned short markerId;
   unsigned short totalCommentLength = 0;
   unsigned int commentIndex;
@@ -577,12 +571,10 @@ ft_t ft;
   return(ST_SUCCESS);
 }
 
-LONG st_aiffread(ft, buf, len)
-ft_t ft;
-LONG *buf, len;
+st_ssize_t st_aiffread(ft_t ft, st_sample_t *buf, st_ssize_t len)
 {
 	aiff_t aiff = (aiff_t ) ft->priv;
-	LONG done;
+	st_ssize_t done;
 
 	/* just read what's left of SSND chunk */
 	if (len > aiff->nsamples)
@@ -594,12 +586,11 @@ LONG *buf, len;
 	return done;
 }
 
-int st_aiffstopread(ft) 
-ft_t ft;
+int st_aiffstopread(ft_t ft) 
 {
 	char buf[5];
-	ULONG chunksize;
-	ULONG trash;
+	uint32_t chunksize;
+	uint32_t trash;
 
 	if (!ft->seekable)
 	{
@@ -616,7 +607,7 @@ ft_t ft;
 			buf, chunksize);
 		if (! strcmp(buf, "MARK") || ! strcmp(buf, "INST"))
 			st_warn("	You're stripping MIDI/loop info!\n");
-		while ((LONG) (--chunksize) >= 0) 
+		while (chunksize-- > 0) 
 		{
 			if (st_readb(ft, (unsigned char *)&trash) == ST_EOF)
 				break;
@@ -638,8 +629,7 @@ ft_t ft;
    Strictly spoken this is not legal, but the playaiff utility
    will still be able to play the resulting file. */
 
-int st_aiffstartwrite(ft)
-ft_t ft;
+int st_aiffstartwrite(ft_t ft)
 {
 	aiff_t aiff = (aiff_t ) ft->priv;
 	int rc;
@@ -674,9 +664,7 @@ ft_t ft;
 	return(aiffwriteheader(ft, 0x7f000000L / (ft->info.size*ft->info.channels)));
 }
 
-LONG st_aiffwrite(ft, buf, len)
-ft_t ft;
-LONG *buf, len;
+st_ssize_t st_aiffwrite(ft_t ft, st_sample_t *buf, st_ssize_t len)
 {
 	aiff_t aiff = (aiff_t ) ft->priv;
 	aiff->nsamples += len;
@@ -684,8 +672,7 @@ LONG *buf, len;
 	return(len);
 }
 
-int st_aiffstopwrite(ft)
-ft_t ft;
+int st_aiffstopwrite(ft_t ft)
 {
 	aiff_t aiff = (aiff_t ) ft->priv;
 	int rc;
@@ -710,9 +697,7 @@ ft_t ft;
 	return(aiffwriteheader(ft, aiff->nsamples / ft->info.channels));
 }
 
-static int aiffwriteheader(ft, nframes)
-ft_t ft;
-LONG nframes;
+static int aiffwriteheader(ft_t ft, st_size_t nframes)
 {
 	int hsize =
 		8 /*COMM hdr*/ + 18 /*COMM chunk*/ +
@@ -721,7 +706,7 @@ LONG nframes;
 	int i;
 	int padded_comment_size = 0;
 	int comment_size = 0;
-	LONG comment_chunk_size = 0L;
+	st_size_t comment_chunk_size = 0L;
 
 	/* MARK and INST chunks */
 	if (ft->instr.nloops) {
@@ -752,7 +737,7 @@ LONG nframes;
 	  padded_comment_size = ((comment_size % 2) == 0) ?
 				comment_size : comment_size + 1;
 	  /* one comment, timestamp, marker ID and text count */
-	  comment_chunk_size = (LONG) (2 + 4 + 2 + 2 + padded_comment_size);
+	  comment_chunk_size = (2L + 4 + 2 + 2 + padded_comment_size);
 	  hsize += 8 /* COMT hdr */ + comment_chunk_size; 
 	}
 
@@ -772,7 +757,7 @@ LONG nframes;
 
 	  /* time stamp of comment, Unix knows of time from 1/1/1970,
 	     Apple knows time from 1/1/1904 */
-	  st_writedw(ft, (LONG) ((LONG) time(NULL)) + 2082844800L);
+	  st_writedw(ft, ((int32_t) time(NULL)) + 2082844800L);
 
 	  /* A marker ID of 0 indicates the comment is not associated
 	     with a marker */
@@ -787,7 +772,7 @@ LONG nframes;
 
 	/* COMM chunk -- describes encoding (and #frames) */
 	st_writes(ft, "COMM");
-	st_writedw(ft, (LONG) 18); /* COMM chunk size */
+	st_writedw(ft, 18); /* COMM chunk size */
 	st_writew(ft, ft->info.channels); /* nchannels */
 	st_writedw(ft, nframes); /* number of frames */
 	st_writew(ft, bits); /* sample width, in bits */
@@ -843,13 +828,12 @@ LONG nframes;
 	st_writes(ft, "SSND");
 	/* chunk size */
 	st_writedw(ft, 8 + nframes * ft->info.channels * ft->info.size); 
-	st_writedw(ft, (LONG) 0); /* offset */
-	st_writedw(ft, (LONG) 0); /* block size */
+	st_writedw(ft, 0); /* offset */
+	st_writedw(ft, 0); /* block size */
 	return(ST_SUCCESS);
 }
 
-static double read_ieee_extended(ft)
-ft_t ft;
+static double read_ieee_extended(ft_t ft)
 {
 	char buf[10];
 	if (fread(buf, 1, 10, ft->fp) != 10)
@@ -860,9 +844,7 @@ ft_t ft;
 	return ConvertFromIeeeExtended(buf);
 }
 
-static void write_ieee_extended(ft, x)
-ft_t ft;
-double x;
+static void write_ieee_extended(ft_t ft, double x)
 {
 	char buf[10];
 	ConvertToIeeeExtended(x, buf);
@@ -915,16 +897,14 @@ double x;
 # define HUGE_VAL HUGE
 #endif /*HUGE_VAL*/
 
-# define FloatToUnsigned(f)      ((ULONG)(((LONG)(f - 2147483648.0)) + 2147483647L) + 1)
+# define FloatToUnsigned(f) ((uint32_t)(((int32_t)(f - 2147483648.0)) + 2147483647L) + 1)
 
-static void ConvertToIeeeExtended(num, bytes)
-double num;
-char *bytes;
+static void ConvertToIeeeExtended(double num, char *bytes)
 {
     int    sign;
     int expon;
     double fMant, fsMant;
-    ULONG hiMant, loMant;
+    uint32_t hiMant, loMant;
 
     if (num < 0) {
         sign = 0x8000;
@@ -1010,28 +990,27 @@ char *bytes;
 # define HUGE_VAL HUGE
 #endif /*HUGE_VAL*/
 
-# define UnsignedToFloat(u)         (((double)((LONG)(u - 2147483647L - 1))) + 2147483648.0)
+# define UnsignedToFloat(u)         (((double)((int32_t)(u - 2147483647L - 1))) + 2147483648.0)
 
 /****************************************************************
  * Extended precision IEEE floating-point conversion routine.
  ****************************************************************/
 
-static double ConvertFromIeeeExtended(bytes)
-unsigned char *bytes;	/* LCN */
+static double ConvertFromIeeeExtended(unsigned char *bytes)
 {
     double    f;
     int    expon;
-    ULONG hiMant, loMant;
+    uint32_t hiMant, loMant;
     
     expon = ((bytes[0] & 0x7F) << 8) | (bytes[1] & 0xFF);
-    hiMant    =    ((ULONG)(bytes[2] & 0xFF) << 24)
-            |    ((ULONG)(bytes[3] & 0xFF) << 16)
-            |    ((ULONG)(bytes[4] & 0xFF) << 8)
-            |    ((ULONG)(bytes[5] & 0xFF));
-    loMant    =    ((ULONG)(bytes[6] & 0xFF) << 24)
-            |    ((ULONG)(bytes[7] & 0xFF) << 16)
-            |    ((ULONG)(bytes[8] & 0xFF) << 8)
-            |    ((ULONG)(bytes[9] & 0xFF));
+    hiMant    =    ((uint32_t)(bytes[2] & 0xFF) << 24)
+            |    ((uint32_t)(bytes[3] & 0xFF) << 16)
+            |    ((uint32_t)(bytes[4] & 0xFF) << 8)
+            |    ((uint32_t)(bytes[5] & 0xFF));
+    loMant    =    ((uint32_t)(bytes[6] & 0xFF) << 24)
+            |    ((uint32_t)(bytes[7] & 0xFF) << 16)
+            |    ((uint32_t)(bytes[8] & 0xFF) << 8)
+            |    ((uint32_t)(bytes[9] & 0xFF));
 
     if (expon == 0 && hiMant == 0 && loMant == 0) {
         f = 0;
