@@ -19,10 +19,13 @@
  * Output is always in big-endian (Sun/NeXT) order.
  */
 
-#include "st.h"
+#include "st_i.h"
 #include "g72x.h"
 #include <stdlib.h>
 #include <string.h>
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
 
 /* Magic numbers used in Sun and NeXT audio files */
 #define SUN_MAGIC 	0x2e736e64		/* Really '.snd' */
@@ -47,9 +50,9 @@
 /* Private data */
 typedef struct aupriv {
 	/* For writer: size in bytes */
-	ULONG data_size;
+	st_size_t data_size;
 	/* For seeking */
-	LONG dataStart;
+	st_size_t dataStart;
 	/* For G72x decoding: */
 	struct g72x_state state;
 	int (*dec_routine)();
@@ -58,12 +61,9 @@ typedef struct aupriv {
 	int in_bits;
 } *au_t;
 
-static void auwriteheader(ft_t ft, ULONG data_size);
+static void auwriteheader(ft_t ft, st_size_t data_size);
 
-int st_auencodingandsize(sun_encoding, encoding, size)
-int sun_encoding;
-int *encoding;
-int *size;
+static int st_auencodingandsize(int sun_encoding, char *encoding, char *size)
 {
     switch (sun_encoding) {
     case SUN_ULAW:
@@ -101,9 +101,7 @@ int *size;
     return(ST_SUCCESS);
 }
 
-int st_auseek(ft,offset) 
-ft_t ft;
-LONG offset;
+int st_auseek(ft_t ft, st_size_t offset) 
 {
 	au_t au = (au_t ) ft->priv;
 
@@ -115,20 +113,19 @@ LONG offset;
 	return(ft->st_errno);
 }
 
-int st_austartread(ft) 
-ft_t ft;
+int st_austartread(ft_t ft) 
 {
 	/* The following 6 variables represent a Sun sound header on disk.
 	   The numbers are written as big-endians.
 	   Any extra bytes (totalling hdr_size - 24) are an
 	   "info" field of unspecified nature, usually a string.
 	   By convention the header size is a multiple of 4. */
-	ULONG magic;
-	ULONG hdr_size;
-	ULONG data_size;
-	ULONG encoding;
-	ULONG sample_rate;
-	ULONG channels;
+	uint32_t magic;
+	uint32_t hdr_size;
+	uint32_t data_size;
+	uint32_t encoding;
+	uint32_t sample_rate;
+	uint32_t channels;
 
 	register int i;
 	char *buf;
@@ -268,8 +265,7 @@ ft_t ft;
    if it is not, the unspecified size remains in the header
    (this is legal). */
 
-int st_austartwrite(ft) 
-ft_t ft;
+int st_austartwrite(ft_t ft) 
 {
 	au_t p = (au_t ) ft->priv;
 	int rc;
@@ -297,10 +293,7 @@ ft_t ft;
  * Returns 1 if there is residual input, returns -1 if eof, else returns 0.
  * (Adapted from Sun's decode.c.)
  */
-static int
-unpack_input(ft, code)
-ft_t			ft;
-unsigned char		*code;
+static int unpack_input(ft_t ft, unsigned char *code)
 {
 	au_t p = (au_t ) ft->priv;
 	unsigned char		in_byte;
@@ -319,9 +312,7 @@ unsigned char		*code;
 	return (p->in_bits > 0);
 }
 
-LONG st_auread(ft, buf, samp)
-ft_t ft;
-LONG *buf, samp;
+st_ssize_t st_auread(ft_t ft, st_sample_t *buf, st_ssize_t samp)
 {
 	au_t p = (au_t ) ft->priv;
 	unsigned char code;
@@ -330,26 +321,23 @@ LONG *buf, samp;
 		return st_rawread(ft, buf, samp);
 	done = 0;
 	while (samp > 0 && unpack_input(ft, &code) >= 0) {
-		*buf++ = LEFT((*p->dec_routine)(code, AUDIO_ENCODING_LINEAR,
-						&p->state),
-			      16);
+		*buf++ = ST_SIGNED_WORD_TO_SAMPLE(
+			(*p->dec_routine)(code, AUDIO_ENCODING_LINEAR,
+	  				  &p->state));
 		samp--;
 		done++;
 	}
 	return done;
 }
 
-LONG st_auwrite(ft, buf, samp)
-ft_t ft;
-LONG *buf, samp;
+st_ssize_t st_auwrite(ft_t ft, st_sample_t *buf, st_ssize_t samp)
 {
 	au_t p = (au_t ) ft->priv;
 	p->data_size += samp * ft->info.size;
 	return(st_rawwrite(ft, buf, samp));
 }
 
-int st_austopwrite(ft)
-ft_t ft;
+int st_austopwrite(ft_t ft)
 {
 	au_t p = (au_t ) ft->priv;
 	int rc;
@@ -374,9 +362,7 @@ ft_t ft;
 	return(ST_SUCCESS);
 }
 
-int st_ausunencoding(size, encoding)
-int size;
-int encoding;
+static int st_ausunencoding(int size, int encoding)
 {
 	int sun_encoding;
 
@@ -393,15 +379,13 @@ int encoding;
 	return sun_encoding;
 }
 
-static void auwriteheader(ft, data_size)
-ft_t ft;
-ULONG data_size;
+static void auwriteheader(ft_t ft, st_size_t data_size)
 {
-	ULONG magic;
-	ULONG hdr_size;
-	ULONG encoding;
-	ULONG sample_rate;
-	ULONG channels;
+	uint32_t magic;
+	uint32_t hdr_size;
+	uint32_t encoding;
+	uint32_t sample_rate;
+	uint32_t channels;
 	int   x;
 	int   comment_size;
 
