@@ -34,18 +34,20 @@
 
 /* ---------------------------------------------------------------------- */
 
-#include <limits.h>
+#include "st_i.h"
+
 #include <math.h>
 #include <string.h>
 #include <time.h>
 #include <stdio.h>
-
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>	/* For SEEK_* defines if not found in stdio */
 #endif
 
 #include "cvsdfilt.h"
-#include "st.h"
 
 /* ---------------------------------------------------------------------- */
 
@@ -95,10 +97,7 @@ struct cvsdpriv {
 
 /* ---------------------------------------------------------------------- */
 
-static float float_conv(fp1, fp2, n)
-float *fp1;
-float *fp2;
-int n;
+static float float_conv(float *fp1, float *fp2,int n)
 {
 	float res = 0;
 	for(; n > 0; n--)
@@ -118,8 +117,7 @@ int n;
  */
 /* ---------------------------------------------------------------------- */
 
-static void cvsdstartcommon(ft)
-ft_t ft;
+static void cvsdstartcommon(ft_t ft)
 {
 	struct cvsdpriv *p = (struct cvsdpriv *) ft->priv;
 	
@@ -161,8 +159,7 @@ ft_t ft;
 
 /* ---------------------------------------------------------------------- */
 
-int st_cvsdstartread(ft) 
-ft_t ft;
+int st_cvsdstartread(ft_t ft) 
 {
 	struct cvsdpriv *p = (struct cvsdpriv *) ft->priv;
 	float *fp1;
@@ -188,8 +185,7 @@ ft_t ft;
 
 /* ---------------------------------------------------------------------- */
 
-int st_cvsdstartwrite(ft) 
-ft_t ft;
+int st_cvsdstartwrite(ft_t ft) 
 {
 	struct cvsdpriv *p = (struct cvsdpriv *) ft->priv;
 	float *fp1;
@@ -211,8 +207,7 @@ ft_t ft;
 
 /* ---------------------------------------------------------------------- */
 
-int st_cvsdstopwrite(ft)
-ft_t ft;
+int st_cvsdstopwrite(ft_t ft)
 {
 	struct cvsdpriv *p = (struct cvsdpriv *) ft->priv;
 
@@ -228,8 +223,7 @@ ft_t ft;
 
 /* ---------------------------------------------------------------------- */
 
-int st_cvsdstopread(ft)
-ft_t ft;
+int st_cvsdstopread(ft_t ft)
 {
 	struct cvsdpriv *p = (struct cvsdpriv *) ft->priv;
 
@@ -251,9 +245,7 @@ static struct {
 } dbg = { NULL, NULL, 0 };
 #endif
 
-LONG st_cvsdread(ft, buf, nsamp) 
-ft_t ft;
-LONG *buf, nsamp;
+st_ssize_t st_cvsdread(ft_t ft, st_sample_t *buf, st_ssize_t nsamp) 
 {
 	struct cvsdpriv *p = (struct cvsdpriv *) ft->priv;
 	int done = 0;
@@ -323,7 +315,7 @@ LONG *buf, nsamp;
 				p->com.v_max = oval;
 			if (oval < p->com.v_min)
 				p->com.v_min = oval;
-			*buf++ = (oval * ((float)LONG_MAX));
+			*buf++ = (oval * ((float)ST_SAMPLE_MAX));
 			done++;
 		}
 		p->com.phase &= 3;
@@ -333,9 +325,7 @@ LONG *buf, nsamp;
 
 /* ---------------------------------------------------------------------- */
 
-LONG st_cvsdwrite(ft, buf, nsamp) 
-ft_t ft;
-LONG *buf, nsamp;
+st_ssize_t st_cvsdwrite(ft_t ft, st_sample_t *buf, st_ssize_t nsamp) 
 {
 	struct cvsdpriv *p = (struct cvsdpriv *) ft->priv;
 	int done = 0;
@@ -369,7 +359,7 @@ LONG *buf, nsamp;
 			memmove(p->c.enc.input_filter+1, p->c.enc.input_filter,
 				sizeof(p->c.enc.input_filter)-sizeof(float));
 			p->c.enc.input_filter[0] = (*buf++) / 
-				((float)LONG_MAX);
+				((float)ST_SAMPLE_MAX);
 			done++;
 		}
 		p->com.phase &= 3;
@@ -428,7 +418,7 @@ struct dvms_header {
 	time_t        Unixtime;
 	unsigned      Usender;
 	unsigned      Ureceiver;
-	ULONG	      Length;
+	st_size_t     Length;
 	unsigned      Srate;
 	unsigned      Days;
 	unsigned      Custom1;
@@ -442,26 +432,22 @@ struct dvms_header {
 
 /* ---------------------------------------------------------------------- */
 /* FIXME: Move these to misc.c */
-static ULONG get32(p)
-unsigned char **p;
+static uint32_t get32(unsigned char **p)
 {
-	ULONG val = (((*p)[3]) << 24) | (((*p)[2]) << 16) | 
+	uint32_t val = (((*p)[3]) << 24) | (((*p)[2]) << 16) | 
 		(((*p)[1]) << 8) | (**p);
 	(*p) += 4;
 	return val;
 }
 
-static unsigned get16(p)
-unsigned char **p;
+static uint16_t get16(unsigned char **p)
 {
 	unsigned val = (((*p)[1]) << 8) | (**p);
 	(*p) += 2;
 	return val;
 }
 
-static void put32(p, val)
-unsigned char **p;
-ULONG val;
+static void put32(unsigned char **p, uint32_t val)
 {
 	*(*p)++ = val & 0xff;
 	*(*p)++ = (val >> 8) & 0xff;
@@ -469,9 +455,7 @@ ULONG val;
 	*(*p)++ = (val >> 24) & 0xff;
 }
 
-static void put16(p, val)
-unsigned char **p;
-unsigned val;
+static void put16(unsigned char **p, int16_t val)
 {
 	*(*p)++ = val & 0xff;
 	*(*p)++ = (val >> 8) & 0xff;
@@ -479,9 +463,7 @@ unsigned val;
 
 /* ---------------------------------------------------------------------- */
 
-static int dvms_read_header(f, hdr)
-FILE *f;
-struct dvms_header *hdr;
+static int dvms_read_header(FILE *f, struct dvms_header *hdr)
 {
 	unsigned char hdrbuf[DVMS_HEADER_LEN];
 	unsigned char *pch = hdrbuf;
@@ -526,9 +508,7 @@ struct dvms_header *hdr;
 /*
  * note! file must be seekable
  */
-static int dvms_write_header(f, hdr)
-FILE *f;
-struct dvms_header *hdr;
+static int dvms_write_header(FILE *f, struct dvms_header *hdr)
 {
 	unsigned char hdrbuf[DVMS_HEADER_LEN];
 	unsigned char *pch = hdrbuf;
@@ -571,9 +551,7 @@ struct dvms_header *hdr;
 
 /* ---------------------------------------------------------------------- */
 
-static void make_dvms_hdr(ft, hdr)
-ft_t ft;
-struct dvms_header *hdr;
+static void make_dvms_hdr(ft_t ft, struct dvms_header *hdr)
 {
 	struct cvsdpriv *p = (struct cvsdpriv *) ft->priv;
 	int len;
@@ -599,8 +577,7 @@ struct dvms_header *hdr;
 
 /* ---------------------------------------------------------------------- */
 
-int st_dvmsstartread(ft) 
-ft_t ft;
+int st_dvmsstartread(ft_t ft) 
 {
 	struct cvsdpriv *p = (struct cvsdpriv *) ft->priv;
 	struct dvms_header hdr;
@@ -639,8 +616,7 @@ ft_t ft;
 
 /* ---------------------------------------------------------------------- */
 
-int st_dvmsstartwrite(ft) 
-ft_t ft;
+int st_dvmsstartwrite(ft_t ft) 
 {
 	struct cvsdpriv *p = (struct cvsdpriv *) ft->priv;
 	struct dvms_header hdr;
@@ -666,8 +642,7 @@ ft_t ft;
 
 /* ---------------------------------------------------------------------- */
 
-int st_dvmsstopwrite(ft)
-ft_t ft;
+int st_dvmsstopwrite(ft_t ft)
 {
 	struct dvms_header hdr;
 	int rc;
