@@ -25,7 +25,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-#include "st.h"
+#include "st_i.h"
 
 #ifndef HAVE_MEMMOVE
 #define memmove(dest,src,len) bcopy((src),(dest),(len))
@@ -39,30 +39,27 @@
 
 /* Private data for Lerp via LCM file */
 typedef struct filterstuff {
-	LONG rate;
-	LONG freq0;										/* low  corner freq */
-	LONG freq1;										/* high corner freq */
-	double beta;   								/* >2 is kaiser window beta, <=2 selects nuttall window */
-	LONG Nwin;
-	Float *Fp;										/* [Xh+1] Filter coefficients */
-	LONG Xh;											/* number of past/future samples needed by filter  */
-	LONG Xt;											/* target to enter new data into X */
-	Float *X, *Y;									/* I/O buffers */
+	st_rate_t rate;
+	st_sample_t freq0;/* low  corner freq */
+	st_sample_t freq1;/* high corner freq */
+	double beta;/* >2 is kaiser window beta, <=2 selects nuttall window */
+	long Nwin;
+	Float *Fp;/* [Xh+1] Filter coefficients */
+	long Xh;/* number of past/future samples needed by filter  */
+	long Xt;/* target to enter new data into X */
+	Float *X, *Y;/* I/O buffers */
 } *filter_t;
 
 /* makeFilter() declared in resample.c */
 extern int 
-makeFilter(Float Fp[], LONG Nwing, double Froll, double Beta, LONG Num, int Normalize);
+makeFilter(Float Fp[], long Nwing, double Froll, double Beta, long Num, int Normalize);
 
-static void FiltWin(filter_t f, LONG Nx);
+static void FiltWin(filter_t f, long Nx);
 
 /*
  * Process options
  */
-int st_filter_getopts(effp, n, argv)
-eff_t effp;
-int n;
-char **argv;
+int st_filter_getopts(eff_t effp, int n, char **argv)
 {
 	filter_t f = (filter_t) effp->priv;
 
@@ -112,12 +109,11 @@ char **argv;
 /*
  * Prepare processing.
  */
-int st_filter_start(effp)
-eff_t effp;
+int st_filter_start(eff_t effp)
 {
 	filter_t f = (filter_t) effp->priv;
 	Float *Fp0, *Fp1;
-	LONG Xh0, Xh1, Xh;
+	long Xh0, Xh1, Xh;
 	int i;
 
 	f->rate = effp->ininfo.rate;
@@ -191,14 +187,11 @@ eff_t effp;
  * Processed signed long samples from ibuf to obuf.
  * Return number of samples processed.
  */
-
-int st_filter_flow(effp, ibuf, obuf, isamp, osamp)
-eff_t effp;
-LONG *ibuf, *obuf;
-LONG *isamp, *osamp;
+int st_filter_flow(eff_t effp, st_sample_t *ibuf, st_sample_t *obuf, 
+                   st_size_t *isamp, st_size_t *osamp)
 {
 	filter_t f = (filter_t) effp->priv;
-	LONG i, Nx, Nproc;
+	long i, Nx, Nproc;
 
 	/* constrain amount we actually process */
 	/* fprintf(stderr,"Xh %d, Xt %d, isamp %d, ",f->Xh, f->Xt, *isamp);fflush(stderr); */
@@ -246,13 +239,11 @@ LONG *isamp, *osamp;
 /*
  * Process tail of input samples.
  */
-int st_filter_drain(effp, obuf, osamp)
-eff_t effp;
-LONG *obuf;
-LONG *osamp;
+int st_filter_drain(eff_t effp, st_sample_t *obuf, st_size_t *osamp)
 {
 	filter_t f = (filter_t) effp->priv;
-	LONG isamp_res, *Obuf, osamp_res;
+	long isamp_res, osamp_res;
+	st_sample_t *Obuf;
 
 	/* fprintf(stderr,"Xh %d, Xt %d  <--- DRAIN\n",f->Xh, f->Xt); */
 
@@ -261,7 +252,7 @@ LONG *osamp;
 	osamp_res = *osamp;
 	Obuf = obuf;
 	while (isamp_res>0 && osamp_res>0) {
-		LONG Isamp, Osamp;
+		st_sample_t Isamp, Osamp;
 		Isamp = isamp_res;
 		Osamp = osamp_res;
 		st_filter_flow(effp, NULL, Obuf, &Isamp, &Osamp);
@@ -282,8 +273,7 @@ LONG *osamp;
  * Do anything required when you stop reading samples.  
  * Don't close input file! 
  */
-int st_filter_stop(effp)
-eff_t effp;
+int st_filter_stop(eff_t effp)
 {
 	filter_t f = (filter_t) effp->priv;
 
@@ -292,14 +282,12 @@ eff_t effp;
 	return (ST_SUCCESS);
 }
 
-static double jprod(Fp, Xp, ct)
-const Float Fp[], *Xp;
-LONG ct;
+static double jprod(const Float *Fp, const Float *Xp, long ct)
 {
 	const Float *fp, *xp, *xq;
 	double v = 0;
 	
-	fp = Fp + ct;				/* so sum starts with smaller coef's */
+	fp = Fp + ct;	/* so sum starts with smaller coef's */
 	xp = Xp - ct;
 	xq = Xp + ct;
 	while (fp > Fp) {   /* ct = 0 can happen */
@@ -310,9 +298,7 @@ LONG ct;
 	return v;
 }
 
-static void FiltWin(f, Nx)
-filter_t f;
-LONG Nx;
+static void FiltWin(filter_t f, long Nx)
 {
 	Float *Y;
 	Float *X, *Xend;
