@@ -17,18 +17,20 @@
  *
  */
 
-#include "st.h"
+#include "st_i.h"
 #include <string.h>
 #include <stdlib.h>
 #include <stdio.h>
-
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>	/* For SEEK_* defines if not found in stdio */
 #endif
 
 /* Private data for MAUD file */
 struct maudstuff { /* max. 100 bytes!!!! */
-	ULONG nsamples;
+	uint32_t nsamples;
 };
 
 static void maudwriteheader(ft_t);
@@ -40,8 +42,7 @@ static void maudwriteheader(ft_t);
  *	size and encoding of samples, 
  *	mono/stereo/quad.
  */
-int st_maudstartread(ft) 
-ft_t ft;
+int st_maudstartread(ft_t ft) 
 {
 	struct maudstuff * p = (struct maudstuff *) ft->priv;
 	
@@ -49,12 +50,12 @@ ft_t ft;
 	char *chunk_buf;
 	
 	unsigned short bitpersam;
-	ULONG nom;
+	uint32_t nom;
 	unsigned short denom;
 	unsigned short chaninf;
 	
-	ULONG chunksize;
-	ULONG trash;
+	uint32_t chunksize;
+	uint32_t trash32;
 	int rc;
 
 	/* Needed for rawread() */
@@ -77,7 +78,7 @@ ft_t ft;
 		return (ST_EOF);
 	}
 	
-	st_readdw(ft, &trash); /* totalsize */
+	st_readdw(ft, &trash32); /* totalsize */
 	
 	if (st_reads(ft, buf, 4) == ST_EOF || strncmp(buf, "MAUD", 4) != 0)
 	{
@@ -112,7 +113,7 @@ ft_t ft;
 			st_readw(ft, &bitpersam);
 
 			/* number of bits per sample after decompression */
-			st_readw(ft, (unsigned short *)&trash);
+			st_readw(ft, (unsigned short *)&trash32);
 
 			st_readdw(ft, &nom);         /* clock source frequency */
 			st_readw(ft, &denom);       /* clock devide           */
@@ -146,9 +147,9 @@ ft_t ft;
 			
 			st_readw(ft, &chaninf); /* compression type */
 			
-			st_readdw(ft, &trash); /* rest of chunk, unused yet */
-			st_readdw(ft, &trash);
-			st_readdw(ft, &trash);
+			st_readdw(ft, &trash32); /* rest of chunk, unused yet */
+			st_readdw(ft, &trash32);
+			st_readdw(ft, &trash32);
 			
 			if (bitpersam == 8 && chaninf == 0) {
 				ft->info.size = ST_SIZE_BYTE;
@@ -225,9 +226,7 @@ ft_t ft;
  * Return number of samples read.
  */
 
-LONG st_maudread(ft, buf, len) 
-ft_t ft;
-LONG *buf, len;
+st_ssize_t st_maudread(ft_t ft, st_sample_t *buf, st_ssize_t len) 
 {
 	return (st_rawread(ft, buf, len));
 }
@@ -236,15 +235,13 @@ LONG *buf, len;
  * Do anything required when you stop reading samples.  
  * Don't close input file! 
  */
-int st_maudstopread(ft) 
-ft_t ft;
+int st_maudstopread(ft_t ft) 
 {
 	/* Needed because of rawread() */
 	return st_rawstopread(ft);
 }
 
-int st_maudstartwrite(ft) 
-ft_t ft;
+int st_maudstartwrite(ft_t ft) 
 {
 	struct maudstuff * p = (struct maudstuff *) ft->priv;
 	int rc;
@@ -286,9 +283,7 @@ ft_t ft;
 	return (ST_SUCCESS);
 }
 
-LONG st_maudwrite(ft, buf, len) 
-ft_t ft;
-LONG *buf, len;
+st_ssize_t st_maudwrite(ft_t ft, st_sample_t *buf, st_ssize_t len) 
 {
 	struct maudstuff * p = (struct maudstuff *) ft->priv;
 	
@@ -297,8 +292,7 @@ LONG *buf, len;
 	return st_rawwrite(ft, buf, len);
 }
 
-int st_maudstopwrite(ft) 
-ft_t ft;
+int st_maudstopwrite(ft_t ft) 
 {
         int rc;
 
@@ -320,8 +314,7 @@ ft_t ft;
 }
 
 #define MAUDHEADERSIZE (4+(4+4+32)+(4+4+32)+(4+4))
-static void maudwriteheader(ft)
-ft_t ft;
+static void maudwriteheader(ft_t ft)
 {
 	struct maudstuff * p = (struct maudstuff *) ft->priv;
 	
@@ -330,8 +323,8 @@ ft_t ft;
 	st_writes(ft, "MAUD"); /* File type */
 	
 	st_writes(ft, "MHDR");
-	st_writedw(ft, (LONG) 8*4); /* number of bytes to follow */
-	st_writedw(ft, (LONG) (p->nsamples ));  /* number of samples stored in MDAT */
+	st_writedw(ft,  8*4); /* number of bytes to follow */
+	st_writedw(ft, p->nsamples);  /* number of samples stored in MDAT */
 	
 	switch (ft->info.encoding) {
 		
@@ -353,7 +346,7 @@ ft_t ft;
 		
 	}
 	
-	st_writedw(ft, (LONG) ft->info.rate); /* clock source frequency */
+	st_writedw(ft, ft->info.rate); /* clock source frequency */
 	st_writew(ft, (int) 1); /* clock devide */
 	
 	if (ft->info.channels == 1) {
@@ -382,12 +375,12 @@ ft_t ft;
 		
 	}
 	
-	st_writedw(ft, (LONG) 0); /* reserved */
-	st_writedw(ft, (LONG) 0); /* reserved */
-	st_writedw(ft, (LONG) 0); /* reserved */
+	st_writedw(ft, 0); /* reserved */
+	st_writedw(ft, 0); /* reserved */
+	st_writedw(ft, 0); /* reserved */
 	
 	st_writes(ft, "ANNO");
-	st_writedw(ft, (LONG) 30); /* length of block */
+	st_writedw(ft, 30); /* length of block */
 	st_writes(ft, "file create by Sound eXchange ");
 	
 	st_writes(ft, "MDAT");
