@@ -1,4 +1,3 @@
-#if	defined(OSS_PLAYER)
 /*
  * Copyright 1997 Chris Bagwell And Sundry Contributors
  * This source code is freely redistributable and may be used for
@@ -26,6 +25,10 @@
  *
  */
 
+#include "st_i.h"
+
+#if	defined(OSS_PLAYER)
+
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -37,11 +40,8 @@
 #include <machine/soundcard.h>
 #endif
 #include <sys/ioctl.h>
-#include "st.h"
-
 /* common r/w initialization code */
-static int ossdspinit(ft)
-ft_t ft;
+static int ossdspinit(ft_t ft)
 {
     int sampletype, samplesize, dsp_stereo;
     int tmp, rc;
@@ -88,11 +88,6 @@ ft_t ft;
 	return(ST_EOF);
     }
 
-    if (ioctl(fileno(ft->fp), SNDCTL_DSP_SYNC, NULL) < 0) {
-	st_fail_errno(ft,ST_EOF,"Unable to sync dsp");
-	return (ST_EOF);
-    }
-
     /* Query the supported formats and find the best match
      */
     rc = ioctl(fileno(ft->fp), SNDCTL_DSP_GETFMTS, &tmp);
@@ -193,6 +188,11 @@ ft_t ft;
 	return (ST_EOF);
     }
 
+    if (ioctl(fileno(ft->fp), SNDCTL_DSP_SYNC, NULL) < 0) {
+	st_fail_errno(ft,ST_EOF,"Unable to sync dsp");
+	return (ST_EOF);
+    }
+
     /* Change to non-buffered I/O */
     setvbuf(ft->fp, NULL, _IONBF, sizeof(char) * ft->file.size);
     return(ST_SUCCESS);
@@ -204,8 +204,7 @@ ft_t ft;
  *	size and encoding of samples,
  *	mono/stereo/quad.
  */
-int st_ossdspstartread(ft)
-ft_t ft;
+int st_ossdspstartread(ft_t ft)
 {
     int rc;
     rc = ossdspinit(ft);
@@ -213,8 +212,7 @@ ft_t ft;
     return rc;
 }
 
-int st_ossdspstartwrite(ft)
-ft_t ft;
+int st_ossdspstartwrite(ft_t ft)
 {
     return ossdspinit(ft);
 }
