@@ -7,31 +7,31 @@
  *   Forced extra comment fields to zero.
  */
 
+#include "st_i.h"
+
 #include <math.h>
 #include <string.h>
 #include <stdio.h>
-
+#ifdef HAVE_ERRNO_H
+#include <errno.h>
+#endif
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>	/* For SEEK_* defines if not found in stdio */
 #endif
 
-#include "st.h"
-
 /* Private data used by writer */
 typedef struct sndpriv {
-        ULONG nsamples;
-		LONG dataStart;
+        st_size_t nsamples;
+	st_size_t dataStart;
 } *snd_t;
 
 #ifndef	SEEK_CUR
 #define	SEEK_CUR	1
 #endif
 
-static void  sndtwriteheader(ft_t ft,LONG nsamples);
+static void  sndtwriteheader(ft_t ft, st_size_t nsamples);
 
-int st_sndseek(ft,offset) 
-ft_t ft;
-LONG offset;
+int st_sndseek(ft_t ft, st_size_t offset) 
 {
 	snd_t snd = (snd_t ) ft->priv;
 
@@ -42,8 +42,7 @@ LONG offset;
 /*                         SNDSTARTREAD                                */
 /*======================================================================*/
 
-int st_sndtstartread(ft)
-ft_t ft;
+int st_sndtstartread(ft_t ft)
 {
 	snd_t snd = (snd_t ) ft->priv;
 
@@ -123,8 +122,7 @@ return (ST_SUCCESS);
 /*======================================================================*/
 /*                         SNDTSTARTWRITE                               */
 /*======================================================================*/
-int st_sndtstartwrite(ft)
-ft_t ft;
+int st_sndtstartwrite(ft_t ft)
 {
 	snd_t p = (snd_t ) ft->priv;
 	int rc;
@@ -151,11 +149,11 @@ sndtwriteheader(ft, 0);
 
 return(ST_SUCCESS);
 }
+
 /*======================================================================*/
 /*                         SNDRSTARTWRITE                               */
 /*======================================================================*/
-int st_sndrstartwrite(ft)
-ft_t ft;
+int st_sndrstartwrite(ft_t ft)
 {
 	int rc;
 
@@ -190,9 +188,7 @@ return(ST_SUCCESS);
 /*                         SNDTWRITE                                     */
 /*======================================================================*/
 
-LONG st_sndtwrite(ft, buf, len)
-ft_t ft;
-LONG *buf, len;
+st_ssize_t st_sndtwrite(ft_t ft, st_sample_t *buf, st_ssize_t len)
 {
 	snd_t p = (snd_t ) ft->priv;
 	p->nsamples += len;
@@ -203,8 +199,7 @@ LONG *buf, len;
 /*                         SNDTSTOPWRITE                                */
 /*======================================================================*/
 
-int st_sndtstopwrite(ft)
-ft_t ft;
+int st_sndtstopwrite(ft_t ft)
 {
 	snd_t p = (snd_t ) ft->priv;
 	int rc;
@@ -229,18 +224,16 @@ ft_t ft;
 /*======================================================================*/
 /*                         SNDTWRITEHEADER                              */
 /*======================================================================*/
-static void sndtwriteheader(ft,nsamples)
-ft_t ft;
-LONG nsamples;
+static void sndtwriteheader(ft_t ft, st_size_t nsamples)
 {
 char name_buf[97];
 
 /* sndtool header */
 st_writes(ft, "SOUND"); /* magic */
 st_writeb(ft, 0x1a);
-st_writew (ft,(LONG)0);  /* hGSound */
+st_writew (ft,0);  /* hGSound */
 st_writedw (ft,nsamples);
-st_writedw (ft,(LONG)0);
+st_writedw (ft,0);
 st_writedw (ft,nsamples);
 st_writew (ft,(int) ft->info.rate);
 st_writew (ft,0);
