@@ -7,7 +7,7 @@
  * the consequences of using this software.
  */
 
-#include "st.h"
+#include "st_i.h"
 #include <string.h>
 #include <ctype.h>
 #include <signal.h>
@@ -78,9 +78,8 @@ void st_fail(const char *fmt, ...)
 
 
 /* Warning: no error checking is done with errstr.  Be sure not to
- * go over the array limit ourself!
- * Note:  Changing vsprintf to vsnprintf should help that but bad
- * references to strings can still cause overflow.
+ * go over the array limit ourself!  vsnprint does not seem to be
+ * on all platforms so not using that.
  */
 void st_fail_errno(ft_t ft, int st_errno, const char *fmt, ...)
 {
@@ -89,7 +88,7 @@ void st_fail_errno(ft_t ft, int st_errno, const char *fmt, ...)
         ft->st_errno = st_errno;
 
         va_start(args, fmt);
-        vsnprintf(ft->st_errstr, 255,fmt, args);
+        vsprintf(ft->st_errstr, fmt, args);
         va_end(args);
         ft->st_errstr[255] = '\0';
 }
@@ -138,8 +137,7 @@ int st_gettype(ft_t formp)
         if (! formp->filetype){
             st_fail_errno(formp,
                           ST_EFMT,
-                          "Must give file type for %s file, either as suffix or with -t option",
-                          formp->filename);
+                          "Filetype was not specified");
                 return(ST_EFMT);
         }
         for(i = 0; st_formats[i].names; i++) {
@@ -154,20 +152,8 @@ int st_gettype(ft_t formp)
                 formp->h = &st_formats[i];
                 return ST_SUCCESS;
         }
-        if (! strcmpcase(formp->filetype, "snd")) {
-                verbose = 1;
-                st_report("File type '%s' is used to name several different formats.", formp->filetype);
-                st_report("If the file came from a Macintosh, it is probably");
-                st_report("a .ub file with a sample rate of 11025 (or possibly 5012 or 22050).");
-                st_report("Use the sequence '-t .ub -r 11025 file.snd'");
-                st_report("If it came from a PC, it's probably a Soundtool file.");
-                st_report("Use the sequence '-t .sndt file.snd'");
-                st_report("If it came from a NeXT, it's probably a .au file.");
-                st_fail_errno(formp,ST_EFMT,"Use the sequence '-t .au file.snd'\n");
-                return ST_EFMT;
-        }
-        st_fail_errno(formp,ST_EFMT,"File type '%s' of %s file is not known!",
-                formp->filetype, formp->filename);
+        st_fail_errno(formp, ST_EFMT, "File type '%s' is not known",
+                      formp->filetype);
         return ST_EFMT;
 }
 
@@ -418,32 +404,32 @@ int st_checkformat(ft_t ft)
 
         if (ft->info.rate == 0)
         {
-                st_fail_errno(ft,ST_EFMT,"Sampling rate for %s file was not given\n", ft->filename);
+                st_fail_errno(ft,ST_EFMT,"sampling rate was not specified");
                 return ST_EOF;
         }
 
         if (ft->info.size == -1)
         {
-                st_fail_errno(ft,ST_EFMT,"Data size was not given for %s file\nUse one of -b/-w/-l/-f/-d/-D", ft->filename);
+                st_fail_errno(ft,ST_EFMT,"data size was not specified");
                 return ST_EOF;
         }
 
-        if (ft->info.encoding == -1 && ft->info.size != ST_SIZE_FLOAT)
+        if (ft->info.encoding == -1)
         {
-                st_fail_errno(ft,ST_EFMT,"Data encoding was not given for %s file\nUse one of -s/-u/-U/-A", ft->filename);
+                st_fail_errno(ft,ST_EFMT,"data encoding was not specified");
                 return ST_EOF;
         }
 
-        if ((ft->info.size <= 0) || (ft->info.size > ST_SIZE_MAX))
+        if ((ft->info.size <= 0) || (ft->info.size > ST_INFO_SIZE_MAX))
         {
-                st_fail_errno(ft,ST_EFMT,"Data size %i for %s file is bogus\n", ft->info.size, ft->filename);
+                st_fail_errno(ft,ST_EFMT,"data size %i is invalid");
                 return ST_EOF;
         }
 
         /* anyway to check length on st_encoding_str[] ? */
         if (ft->info.encoding <= 0  || ft->info.encoding > ST_ENCODING_MAX)
         {
-                st_fail_errno(ft,ST_EFMT,"Data encoding %i for %s file is bogus\n", ft->info.encoding, ft->filename);
+                st_fail_errno(ft,ST_EFMT,"data encoding %i is invalid");
                 return ST_EOF;
         }
 
@@ -482,7 +468,7 @@ void sigintreg(ft_t ft)
  * # of samples.
  * Returns ST_EOF on error.
  */
-int st_parsesamples(ULONG rate, char *str, ULONG *samples, char def)
+int st_parsesamples(st_rate_t rate, char *str, st_size_t *samples, char def)
 {
     int found_samples = 0, found_time = 0;
     int time;
