@@ -67,12 +67,12 @@
 #include <unistd.h>		/* For SEEK_* defines if not found in stdio */
 #endif
 
-#include "st.h"
+#include "st_i.h"
 #include "wav.h"
 #include "ima_rw.h"
 #include "adpcm.h"
-#ifdef HAVE_LIBGSM
-#include "gsm.h"
+#ifdef ENABLE_GSM
+#include "gsm/gsm.h"
 #endif
 
 #undef PAD_NSAMPS
@@ -80,13 +80,13 @@
 
 /* Private data for .wav file */
 typedef struct wavstuff {
-    LONG	   numSamples;     /* samples/channel reading: starts at total count and decremented  */
+    st_size_t	   numSamples;     /* samples/channel reading: starts at total count and decremented  */
     		                   /* writing: starts at 0 and counts samples written */
-    ULONG	   dataLength;     /* needed for ADPCM writing */
+    st_size_t	   dataLength;     /* needed for ADPCM writing */
     unsigned short formatTag;	   /* What type of encoding file is using */
     unsigned short samplesPerBlock;
     unsigned short blockAlign;
-    LONG dataStart;  /* need to for seeking */
+    st_size_t dataStart;  /* need to for seeking */
     
     /* following used by *ADPCM wav files */
     unsigned short nCoefs;	    /* ADPCM: number of coef sets */
@@ -99,7 +99,7 @@ typedef struct wavstuff {
     int 	   state[16];       /* step-size info for *ADPCM writes */
 
     /* following used by GSM 6.10 wav */
-#ifdef HAVE_LIBGSM
+#ifdef ENABLE_GSM
     gsm		   gsmhandle;
     gsm_signal	   *gsmsample;
     int		   gsmindex;
@@ -127,8 +127,7 @@ static int wavwritehdr(ft_t, int);
  * ImaAdpcmReadBlock - Grab and decode complete block of samples
  *
  */
-unsigned short  ImaAdpcmReadBlock(ft)
-ft_t ft;    
+unsigned short  ImaAdpcmReadBlock(ft_t ft)
 {
     wav_t	wav = (wav_t) ft->priv;
     int bytesRead;
@@ -168,8 +167,7 @@ ft_t ft;
  * AdpcmReadBlock - Grab and decode complete block of samples
  *
  */
-unsigned short  AdpcmReadBlock(ft)
-ft_t ft;    
+unsigned short  AdpcmReadBlock(ft_t ft)
 {
     wav_t	wav = (wav_t) ft->priv;
     int bytesRead;
@@ -204,8 +202,7 @@ ft_t ft;
 /* Common ADPCM Write Function                                              */
 /****************************************************************************/
 
-static int xxxAdpcmWriteBlock(ft)
-ft_t ft;
+static int xxxAdpcmWriteBlock(ft_t ft)
 {
     wav_t wav = (wav_t) ft->priv;
     int chans, ct;
@@ -244,10 +241,9 @@ ft_t ft;
 /****************************************************************************/
 /* WAV GSM6.10 support functions                                            */
 /****************************************************************************/
-#ifdef HAVE_LIBGSM
+#ifdef ENABLE_GSM
 /* create the gsm object, malloc buffer for 160*2 samples */
-int wavgsminit(ft)
-ft_t ft;
+int wavgsminit(ft_t ft)
 {	
     int valueP=1;
     wav_t	wav = (wav_t) ft->priv;
@@ -274,17 +270,14 @@ ft_t ft;
 }
 
 /*destroy the gsm object and free the buffer */
-void wavgsmdestroy(ft)
-ft_t ft;
+void wavgsmdestroy(ft_t ft)
 {	
     wav_t	wav = (wav_t) ft->priv;
     gsm_destroy(wav->gsmhandle);
     free(wav->gsmsample);
 }
 
-LONG wavgsmread(ft, buf, len)
-ft_t ft;
-LONG *buf, len;
+st_ssize_t wavgsmread(ft_t ft, st_sample_t *buf, st_ssize_t len)
 {
     wav_t	wav = (wav_t) ft->priv;
     int done=0;
@@ -295,7 +288,7 @@ LONG *buf, len;
 
   /* copy out any samples left from the last call */
     while(wav->gsmindex && (wav->gsmindex<160*2) && (done < len))
-	buf[done++]=LEFT(wav->gsmsample[wav->gsmindex++],16);
+	buf[done++]=ST_SIGNED_WORD_TO_SAMPLE(wav->gsmsample[wav->gsmindex++]);
 
   /* read and decode loop, possibly leaving some samples in wav->gsmsample */
     while (done < len) {
@@ -321,16 +314,14 @@ LONG *buf, len;
 	}
 
 	while ((wav->gsmindex <160*2) && (done < len)){
-	    buf[done++]=LEFT(wav->gsmsample[(wav->gsmindex)++],16);
+	    buf[done++]=ST_SIGNED_WORD_TO_SAMPLE(wav->gsmsample[(wav->gsmindex)++]);
 	}
     }
 
     return done;
 }
 
-static int wavgsmflush(ft, pad)
-ft_t ft;
-int pad; /* normally 0, but 1 to pad last write to even datalen */
+static int wavgsmflush(ft_t ft, int pad)
 {
     gsm_byte	frame[65];
     wav_t	wav = (wav_t) ft->priv;
@@ -364,9 +355,7 @@ int pad; /* normally 0, but 1 to pad last write to even datalen */
     return (ST_SUCCESS);
 }
 
-LONG wavgsmwrite(ft, buf, len)
-ft_t ft;
-LONG *buf, len;
+st_ssize_t wavgsmwrite(ft_t ft, st_sample_t *buf, st_ssize_t len)
 {
     wav_t	wav = (wav_t) ft->priv;
     int done = 0;
@@ -376,7 +365,8 @@ LONG *buf, len;
 
     while (done < len) {
 	while ((wav->gsmindex < 160*2) && (done < len))
-	    wav->gsmsample[(wav->gsmindex)++] = RIGHT(buf[done++], 16);
+	    wav->gsmsample[(wav->gsmindex)++] = 
+		ST_SAMPLE_TO_SIGNED_WORD(buf[done++]);
 
 	if (wav->gsmindex < 160*2)
 	    break;
@@ -389,8 +379,7 @@ LONG *buf, len;
 
 }
 
-void wavgsmstopwrite(ft)
-ft_t ft;
+void wavgsmstopwrite(ft_t ft)
 {
     wav_t	wav = (wav_t) ft->priv;
 
@@ -406,23 +395,10 @@ ft_t ft;
 /* General Sox WAV file code                                                */
 /****************************************************************************/
 
-/* FIXME: Use common misc.c skip code 
-
-moved to misc.c using st_seek(ft,len,SEEK_CUR) instead
-
-static void fSkip(FILE *fp, ULONG len)
-{
-    while (len > 0 && !feof(fp))
-    {
-	getc(fp);
-	len--;
-    }
-}
-*/
-static ULONG findChunk(ft_t ft, const char *Label)
+static uint32_t findChunk(ft_t ft, const char *Label)
 {
     char magic[5];
-    ULONG len;
+    uint32_t len;
     for (;;)
     {
 	if (st_reads(ft, magic, 4) == ST_EOF)
@@ -448,27 +424,27 @@ static ULONG findChunk(ft_t ft, const char *Label)
  *	size and encoding of samples, 
  *	mono/stereo/quad.
  */
-int st_wavstartread(ft) 
-ft_t ft;
+int st_wavstartread(ft_t ft) 
 {
     wav_t	wav = (wav_t) ft->priv;
     char	magic[5];
-    ULONG	len;
+    uint32_t	len;
     int		rc;
 
     /* wave file characteristics */
-    ULONG    wRiffLength;
+    uint32_t      dwRiffLength;
     unsigned short wChannels;	    /* number of channels */
-    ULONG    wSamplesPerSecond;     /* samples per second per channel */
-    ULONG    wAvgBytesPerSec;	    /* estimate of bytes per second needed */
-    unsigned short wBitsPerSample;  /* bits per sample */
-    unsigned short wFmtSize;
-    unsigned short wExtSize = 0;    /* extended field for non-PCM */
+    uint32_t      dwSamplesPerSecond; /* samples per second per channel */
+    uint32_t      dwAvgBytesPerSec;/* estimate of bytes per second needed */
+    uint16_t wBitsPerSample;  /* bits per sample */
+    uint32_t wFmtSize;
+    uint16_t wExtSize = 0;    /* extended field for non-PCM */
 
-    ULONG    wDataLength;	    /* length of sound data in bytes */
-    ULONG    bytesPerBlock = 0;
-    ULONG    bytespersample;	    /* bytes per sample (per channel */
-	char text[256];
+    uint32_t      dwDataLength;    /* length of sound data in bytes */
+    st_size_t    bytesPerBlock = 0;
+    int    bytespersample;	    /* bytes per sample (per channel */
+    char text[256];
+    uint32_t      dwLoopPos;
 
 	ft->st_errno = ST_SUCCESS;
 
@@ -480,7 +456,7 @@ ft_t ft;
 	return ST_EOF;
     }
 
-    st_readdw(ft, &wRiffLength);
+    st_readdw(ft, &dwRiffLength);
 
     if (st_reads(ft, magic, 4) == ST_EOF || strncmp("WAVE", magic, 4))
     {
@@ -500,8 +476,8 @@ ft_t ft;
 
     st_readw(ft, &(wav->formatTag));
     st_readw(ft, &wChannels);
-    st_readdw(ft, &wSamplesPerSecond);
-    st_readdw(ft, &wAvgBytesPerSec);	/* Average bytes/second */
+    st_readdw(ft, &dwSamplesPerSecond);
+    st_readdw(ft, &dwAvgBytesPerSec);	/* Average bytes/second */
     st_readw(ft, &(wav->blockAlign));	/* Block align */
     st_readw(ft, &wBitsPerSample);	/* bits per sample per channel */
     len -= 16;
@@ -516,7 +492,7 @@ ft_t ft;
 	/* Default (-1) depends on sample size.  Set that later on. */
 	if (ft->info.encoding != -1 && ft->info.encoding != ST_ENCODING_UNSIGNED &&
 	    ft->info.encoding != ST_ENCODING_SIGN2)
-	    st_warn("User options overriding encoding read in .wav header");
+	    st_report("User options overriding encoding read in .wav header");
 
 	/* Needed by rawread() functions */
         rc = st_rawstartread(ft);
@@ -529,14 +505,14 @@ ft_t ft;
 	if (ft->info.encoding == -1 || ft->info.encoding == ST_ENCODING_IMA_ADPCM)
 	    ft->info.encoding = ST_ENCODING_IMA_ADPCM;
 	else
-	    st_warn("User options overriding encoding read in .wav header");
+	    st_report("User options overriding encoding read in .wav header");
 	break;
 
     case WAVE_FORMAT_ADPCM:
 	if (ft->info.encoding == -1 || ft->info.encoding == ST_ENCODING_ADPCM)
 	    ft->info.encoding = ST_ENCODING_ADPCM;
 	else
-	    st_warn("User options overriding encoding read in .wav header");
+	    st_report("User options overriding encoding read in .wav header");
 	break;
 
     case WAVE_FORMAT_IEEE_FLOAT:
@@ -547,7 +523,7 @@ ft_t ft;
 	if (ft->info.encoding == -1 || ft->info.encoding == ST_ENCODING_ALAW)
 	    ft->info.encoding = ST_ENCODING_ALAW;
 	else
-	    st_warn("User options overriding encoding read in .wav header");
+	    st_report("User options overriding encoding read in .wav header");
 
 	/* Needed by rawread() functions */
         rc = st_rawstartread(ft);
@@ -560,7 +536,7 @@ ft_t ft;
 	if (ft->info.encoding == -1 || ft->info.encoding == ST_ENCODING_ULAW)
 	    ft->info.encoding = ST_ENCODING_ULAW;
 	else
-	    st_warn("User options overriding encoding read in .wav header");
+	    st_report("User options overriding encoding read in .wav header");
 
 	/* Needed by rawread() functions */
         rc = st_rawstartread(ft);
@@ -582,11 +558,11 @@ ft_t ft;
 	st_fail_errno(ft,ST_EHDR,"Sorry, this WAV file is in Dolby AC2 format.");
 	return ST_EOF;
     case WAVE_FORMAT_GSM610:
-#ifdef HAVE_LIBGSM
+#ifdef ENABLE_GSM
 	if (ft->info.encoding == -1 || ft->info.encoding == ST_ENCODING_GSM )
 	    ft->info.encoding = ST_ENCODING_GSM;
 	else
-	    st_warn("User options overriding encoding read in .wav header");
+	    st_report("User options overriding encoding read in .wav header");
 	break;
 #else
 	st_fail_errno(ft,ST_EOF,"Sorry, this WAV file is in GSM6.10 format and no GSM support present, recompile sox with gsm library");
@@ -624,12 +600,12 @@ ft_t ft;
     if (ft->info.channels == -1 || ft->info.channels == wChannels)
 	ft->info.channels = wChannels;
     else
-	st_warn("User options overriding channels read in .wav header");
+	st_report("User options overriding channels read in .wav header");
 
-    if (ft->info.rate == 0 || ft->info.rate == wSamplesPerSecond)
-	ft->info.rate = wSamplesPerSecond;
+    if (ft->info.rate == 0 || ft->info.rate == dwSamplesPerSecond)
+	ft->info.rate = dwSamplesPerSecond;
     else
-	st_warn("User options overriding rate read in .wav header");
+	st_report("User options overriding rate read in .wav header");
     
 
     wav->iCoefs = NULL;
@@ -654,7 +630,6 @@ ft_t ft;
 
     switch (wav->formatTag)
     {
-    /* ULONG max_spb; */
     case WAVE_FORMAT_ADPCM:
 	if (wExtSize < 4)
 	{
@@ -767,7 +742,7 @@ ft_t ft;
 	bytespersample = ST_SIZE_WORD;  /* AFTER de-compression */
 	break;
 
-#ifdef HAVE_LIBGSM
+#ifdef ENABLE_GSM
     /* GSM formats have extended fmt chunk.  Check for those cases. */
     case WAVE_FORMAT_GSM610:
 	if (wExtSize < 2)
@@ -849,7 +824,7 @@ ft_t ft;
      * the upcoming 'data' chunk */
 
     /* Now look for the wave data chunk */
-    wDataLength = len = findChunk(ft, "data");
+    dwDataLength = len = findChunk(ft, "data");
     /* findChunk() only returns if chunk was found */
 
 	/* Data starts here */
@@ -860,8 +835,9 @@ ft_t ft;
 
     case WAVE_FORMAT_ADPCM:
 	wav->numSamples = 
-	    AdpcmSamplesIn(wDataLength, ft->info.channels, wav->blockAlign, wav->samplesPerBlock);
-	/*st_report("datalen %d, numSamples %d",wDataLength, wav->numSamples);*/
+	    AdpcmSamplesIn(dwDataLength, ft->info.channels, 
+		           wav->blockAlign, wav->samplesPerBlock);
+	/*st_report("datalen %d, numSamples %d",dwDataLength, wav->numSamples);*/
 	wav->blockSamplesRemaining = 0;	       /* Samples left in buffer */
 	ft->length = wav->numSamples*ft->info.channels;
 	break;
@@ -870,32 +846,33 @@ ft_t ft;
 	/* Compute easiest part of number of samples.  For every block, there
 	   are samplesPerBlock samples to read. */
 	wav->numSamples = 
-	    ImaSamplesIn(wDataLength, ft->info.channels, wav->blockAlign, wav->samplesPerBlock);
-	/*st_report("datalen %d, numSamples %d",wDataLength, wav->numSamples);*/
+	    ImaSamplesIn(dwDataLength, ft->info.channels, 
+		         wav->blockAlign, wav->samplesPerBlock);
+	/*st_report("datalen %d, numSamples %d",dwDataLength, wav->numSamples);*/
 	wav->blockSamplesRemaining = 0;	       /* Samples left in buffer */
 	initImaTable();
 	ft->length = wav->numSamples*ft->info.channels;
 	break;
 
-#ifdef HAVE_LIBGSM
+#ifdef ENABLE_GSM
     case WAVE_FORMAT_GSM610:
-	wav->numSamples = (((wDataLength / wav->blockAlign) * wav->samplesPerBlock) * ft->info.channels);
+	wav->numSamples = (((dwDataLength / wav->blockAlign) * wav->samplesPerBlock) * ft->info.channels);
 	wavgsminit(ft);
 	ft->length = wav->numSamples;
 	break;
 #endif
 
     default:
-	wav->numSamples = wDataLength/ft->info.size;	/* total samples */
+	wav->numSamples = dwDataLength/ft->info.size;	/* total samples */
 	ft->length = wav->numSamples;
 
     }
 
     st_report("Reading Wave file: %s format, %d channel%s, %d samp/sec",
 	   wav_format_str(wav->formatTag), ft->info.channels,
-	   wChannels == 1 ? "" : "s", wSamplesPerSecond);
+	   wChannels == 1 ? "" : "s", dwSamplesPerSecond);
     st_report("        %d byte/sec, %d block align, %d bits/samp, %u data bytes",
-	   wAvgBytesPerSec, wav->blockAlign, wBitsPerSample, wDataLength);
+	   dwAvgBytesPerSec, wav->blockAlign, wBitsPerSample, dwDataLength);
 
     /* Can also report extended fmt information */
     switch (wav->formatTag)
@@ -910,7 +887,7 @@ ft_t ft;
 		wExtSize,wav->samplesPerBlock,bytesPerBlock);
 	break;
 
-#ifdef HAVE_LIBGSM
+#ifdef ENABLE_GSM
     case WAVE_FORMAT_GSM610:
 	st_report("GSM .wav: %d Extsize, %d Samps/block,  %d samples",
 		wExtSize,wav->samplesPerBlock,wav->numSamples);
@@ -951,7 +928,8 @@ ft_t ft;
 			st_readdw(ft,&len);
 			len = (len + 1) & ~1;
 			st_seek(ft,len-4,SEEK_CUR);
-			st_readdw(ft,(ULONG*)&ft->loops[0].start); 
+			st_readdw(ft,&dwLoopPos);
+			ft->loops[0].start = dwLoopPos;
 		} else if(strncmp(magic,"note",4) == 0){
 			/*Skip*/
 			st_readdw(ft,&len);
@@ -961,8 +939,8 @@ ft_t ft;
 			/*Skip*/
 		} else if(strncmp(magic,"ltxt",4) == 0){
 			st_seek(ft,4,SEEK_CUR);
-			st_readdw(ft,(ULONG*)&ft->loops[0].length); 
-			ft->loops[0].length = ft->loops[0].length - ft->loops[0].start;
+			st_readdw(ft,&dwLoopPos);
+			ft->loops[0].length = dwLoopPos - ft->loops[0].start;
 		} else if(strncmp(magic,"labl",4) == 0){
 			/*Skip*/
 			st_readdw(ft,&len);
@@ -985,12 +963,10 @@ ft_t ft;
  * Return number of samples read.
  */
 
-LONG st_wavread(ft, buf, len) 
-ft_t ft;
-LONG *buf, len;
+st_ssize_t st_wavread(ft_t ft, st_sample_t *buf, st_ssize_t len) 
 {
 	wav_t	wav = (wav_t) ft->priv;
-	LONG	done;
+	st_ssize_t done;
 
 	ft->st_errno = ST_SUCCESS;
 	
@@ -1025,7 +1001,7 @@ LONG *buf, len;
 		    wav->samplePtr = wav->samples;
 		}
 
-		/* Copy interleaved data into buf, converting short to LONG */
+		/* Copy interleaved data into buf, converting to st_sample_t */
 		{
 		    short *p, *top;
 		    int ct;
@@ -1039,7 +1015,7 @@ LONG *buf, len;
 		    top = p+ct;
 		    /* Output is already signed */
 		    while (p<top)
-			*buf++ = LEFT((*p++), 16);
+			*buf++ = ST_SIGNED_WORD_TO_SAMPLE((*p++));
 
 		    wav->samplePtr = p;
 		}
@@ -1052,7 +1028,7 @@ LONG *buf, len;
 	    return done;
 	    break;
 
-#ifdef HAVE_LIBGSM
+#ifdef ENABLE_GSM
 	case ST_ENCODING_GSM:
 	    if (len > wav->numSamples) 
 	        len = wav->numSamples;
@@ -1081,8 +1057,7 @@ LONG *buf, len;
  * Do anything required when you stop reading samples.  
  * Don't close input file! 
  */
-int st_wavstopread(ft) 
-ft_t ft;
+int st_wavstopread(ft_t ft) 
 {
     wav_t	wav = (wav_t) ft->priv;
     int		rc = ST_SUCCESS;
@@ -1095,7 +1070,7 @@ ft_t ft;
 
     switch (ft->info.encoding)
     {
-#ifdef HAVE_LIBGSM
+#ifdef ENABLEGSM
     case ST_ENCODING_GSM:
 	wavgsmdestroy(ft);
 	break;
@@ -1110,8 +1085,7 @@ ft_t ft;
     return rc;
 }
 
-int st_wavstartwrite(ft) 
-ft_t ft;
+int st_wavstartwrite(ft_t ft) 
 {
 	wav_t	wav = (wav_t) ft->priv;
 	int	rc;
@@ -1165,7 +1139,7 @@ ft_t ft;
 	    wav->samplePtr = wav->samples;
 	    break;
 
-#ifdef HAVE_LIBGSM
+#ifdef ENABLE_GSM
 	case WAVE_FORMAT_GSM610:
 	    wavgsminit(ft);
 	    break;
@@ -1186,38 +1160,38 @@ bytes      variable      description
 16 - 19    wFmtSize       length of format chunk minus 8 byte header 
 20 - 21    wFormatTag     identifies PCM, ULAW etc
 22 - 23    wChannels      
-24 - 27    wSamplesPerSecond   samples per second per channel
-28 - 31    wAvgBytesPerSec     non-trivial for compressed formats
+24 - 27    dwSamplesPerSecond  samples per second per channel
+28 - 31    dwAvgBytesPerSec    non-trivial for compressed formats
 32 - 33    wBlockAlign         basic block size
 34 - 35    wBitsPerSample      non-trivial for compressed formats
 
 PCM formats then go straight to the data chunk:
 36 - 39    'data'
-40 - 43     wDataLength   length of data chunk minus 8 byte header
-44 - (wDataLength + 43)    the data
+40 - 43     dwDataLength   length of data chunk minus 8 byte header
+44 - (dwDataLength + 43)   the data
 
 non-PCM formats must write an extended format chunk and a fact chunk:
 
 ULAW, ALAW formats:
 36 - 37    wExtSize = 0  the length of the format extension
 38 - 41    'fact'
-42 - 45    wFactSize = 4  length of the fact chunk minus 8 byte header
-46 - 49    wSamplesWritten   actual number of samples written out
+42 - 45    dwFactSize = 4  length of the fact chunk minus 8 byte header
+46 - 49    dwSamplesWritten   actual number of samples written out
 50 - 53    'data'
-54 - 57     wDataLength   length of data chunk minus 8 byte header
-58 - (wDataLength + 57)    the data
+54 - 57     dwDataLength  length of data chunk minus 8 byte header
+58 - (dwDataLength + 57)  the data
 
 
 GSM6.10  format:
 36 - 37    wExtSize = 2 the length in bytes of the format-dependent extension
 38 - 39    320           number of samples per  block 
 40 - 43    'fact'
-44 - 47    wFactSize = 4  length of the fact chunk minus 8 byte header
-48 - 51    wSamplesWritten   actual number of samples written out
+44 - 47    dwFactSize = 4  length of the fact chunk minus 8 byte header
+48 - 51    dwSamplesWritten   actual number of samples written out
 52 - 55    'data'
-56 - 59     wDataLength   length of data chunk minus 8 byte header
-60 - (wDataLength + 59)     the data
-(+ a padding byte if wDataLength is odd) 
+56 - 59     dwDataLength  length of data chunk minus 8 byte header
+60 - (dwDataLength + 59)  the data
+(+ a padding byte if dwDataLength is odd) 
 
 
 note that header contains (up to) 3 separate ways of describing the
@@ -1226,285 +1200,281 @@ samples wav->numSamples in a way that is non-trivial for the blocked
 and padded compressed formats:
 
 wRiffLength -      (riff header) the length of the file, minus 8 
-wSamplesWritten  -  (fact header) the number of samples written (after padding
+dwSamplesWritten - (fact header) the number of samples written (after padding
                    to a complete block eg for GSM)
-wDataLength     -   (data chunk header) the number of (valid) data bytes written
+dwDataLength     - (data chunk header) the number of (valid) data bytes written
 
 */
 
-static int wavwritehdr(ft, second_header) 
-ft_t ft;
-int second_header;
+static int wavwritehdr(ft_t ft, int second_header) 
 {
-	wav_t	wav = (wav_t) ft->priv;
+    wav_t	wav = (wav_t) ft->priv;
 
-	/* variables written to wav file header */
-	/* RIFF header */    
-	ULONG wRiffLength ;                 /* length of file after 8 byte riff header */
-	/* fmt chunk */
-	ULONG wFmtSize = 16;                /* size field of the fmt chunk */
-	unsigned short wFormatTag = 0;      /* data format */
-	unsigned short wChannels;           /* number of channels */
-	ULONG  wSamplesPerSecond;           /* samples per second per channel*/
-	ULONG  wAvgBytesPerSec=0;           /* estimate of bytes per second needed */
-	unsigned short wBlockAlign=0;       /* byte alignment of a basic sample block */
-	unsigned short wBitsPerSample=0;    /* bits per sample */
-	/* fmt chunk extension (not PCM) */
-	unsigned short wExtSize=0;          /* extra bytes in the format extension */
-	unsigned short wSamplesPerBlock;    /* samples per channel per block */
-	/* wSamplesPerBlock and other things may go into format extension */
+    /* variables written to wav file header */
+    /* RIFF header */    
+    uint32_t wRiffLength ;  /* length of file after 8 byte riff header */
+    /* fmt chunk */
+    uint16_t wFmtSize = 16;       /* size field of the fmt chunk */
+    uint16_t wFormatTag = 0;      /* data format */
+    uint16_t wChannels;           /* number of channels */
+    uint32_t dwSamplesPerSecond;  /* samples per second per channel*/
+    uint32_t dwAvgBytesPerSec=0;  /* estimate of bytes per second needed */
+    uint16_t wBlockAlign=0;       /* byte alignment of a basic sample block */
+    uint16_t wBitsPerSample=0;    /* bits per sample */
+    /* fmt chunk extension (not PCM) */
+    uint16_t wExtSize=0;          /* extra bytes in the format extension */
+    uint16_t wSamplesPerBlock;    /* samples per channel per block */
+    /* wSamplesPerBlock and other things may go into format extension */
 
-	/* fact chunk (not PCM) */
-	ULONG wFactSize=4;		/* length of the fact chunk */
-	ULONG wSamplesWritten=0;	/* windows doesnt seem to use this*/
+    /* fact chunk (not PCM) */
+    uint32_t dwFactSize=4;	  /* length of the fact chunk */
+    uint32_t dwSamplesWritten=0;  /* windows doesnt seem to use this*/
 
-	/* data chunk */
-	ULONG  wDataLength=0x7ffff000L;	/* length of sound data in bytes */
-	/* end of variables written to header */
+    /* data chunk */
+    uint32_t  dwDataLength=0x7ffff000L;	/* length of sound data in bytes */
+    /* end of variables written to header */
 
-	/* internal variables, intermediate values etc */
-	ULONG bytespersample; 		/* (uncompressed) bytes per sample (per channel) */
-	ULONG blocksWritten = 0;
+    /* internal variables, intermediate values etc */
+    int bytespersample; /* (uncompressed) bytes per sample (per channel) */
+    long blocksWritten = 0;
 
-	wSamplesPerSecond = ft->info.rate;
-	wChannels = ft->info.channels;
+    dwSamplesPerSecond = ft->info.rate;
+    wChannels = ft->info.channels;
 
-	/* Check to see if encoding is ADPCM or not.  If ADPCM
-	 * possibly override the size to be bytes.  It isn't needed
-	 * by this routine will look nicer (and more correct)
-	 * on verbose output.
-	 */
-	if ((ft->info.encoding == ST_ENCODING_ADPCM ||
-	     ft->info.encoding == ST_ENCODING_IMA_ADPCM ||
-	     ft->info.encoding == ST_ENCODING_GSM) &&
-	    ft->info.size != ST_SIZE_BYTE)
-	{
-	    st_warn("Overriding output size to bytes for compressed data.");
-	    ft->info.size = ST_SIZE_BYTE;
-	}
+    /* Check to see if encoding is ADPCM or not.  If ADPCM
+     * possibly override the size to be bytes.  It isn't needed
+     * by this routine will look nicer (and more correct)
+     * on verbose output.
+     */
+    if ((ft->info.encoding == ST_ENCODING_ADPCM ||
+	 ft->info.encoding == ST_ENCODING_IMA_ADPCM ||
+	 ft->info.encoding == ST_ENCODING_GSM) &&
+	 ft->info.size != ST_SIZE_BYTE)
+    {
+	st_warn("Overriding output size to bytes for compressed data.");
+	ft->info.size = ST_SIZE_BYTE;
+    }
 
-	switch (ft->info.size)
-	{
-		case ST_SIZE_BYTE:
-		        wBitsPerSample = 8;
-			if (ft->info.encoding != ST_ENCODING_UNSIGNED &&
-			    ft->info.encoding != ST_ENCODING_ULAW &&
-			    ft->info.encoding != ST_ENCODING_ALAW &&
-			    ft->info.encoding != ST_ENCODING_GSM &&
-			    ft->info.encoding != ST_ENCODING_ADPCM &&
-			    ft->info.encoding != ST_ENCODING_IMA_ADPCM)
-			{
-				st_warn("Do not support %s with 8-bit data.  Forcing to unsigned",st_encodings_str[ft->info.encoding]);
-				ft->info.encoding = ST_ENCODING_UNSIGNED;
-			}
-			break;
-		case ST_SIZE_WORD:
-			wBitsPerSample = 16;
-			if (ft->info.encoding != ST_ENCODING_SIGN2)
-			{
-				st_warn("Do not support %s with 16-bit data.  Forcing to Signed.",st_encodings_str[ft->info.encoding]);
-				ft->info.encoding = ST_ENCODING_SIGN2;
-			}
-			break;
-		case ST_SIZE_DWORD:
-			wBitsPerSample = 32;
-			if (ft->info.encoding != ST_ENCODING_SIGN2)
-			{
-				st_warn("Do not support %s with 16-bit data.  Forcing to Signed.",st_encodings_str[ft->info.encoding]);
-				ft->info.encoding = ST_ENCODING_SIGN2;
-			}
-
-			break;
-		default:
-			st_warn("Do not support %s in WAV files.  Forcing to Signed Words.",st_sizes_str[ft->info.size]);
-			ft->info.encoding = ST_ENCODING_SIGN2;
-			ft->info.size = ST_SIZE_WORD;
-			wBitsPerSample = 16;
-			break;
-	}
-
-	wSamplesPerBlock = 1;	/* common default for PCM data */
-
-	switch (ft->info.encoding)
-	{
-		case ST_ENCODING_UNSIGNED:
-		case ST_ENCODING_SIGN2:
-			wFormatTag = WAVE_FORMAT_PCM;
-	    		bytespersample = (wBitsPerSample + 7)/8;
-	    		wBlockAlign = wChannels * bytespersample;
-			break;
-		case ST_ENCODING_ALAW:
-			wFormatTag = WAVE_FORMAT_ALAW;
-	    		wBlockAlign = wChannels;
-			break;
-		case ST_ENCODING_ULAW:
-			wFormatTag = WAVE_FORMAT_MULAW;
-	    		wBlockAlign = wChannels;
-			break;
-		case ST_ENCODING_IMA_ADPCM:
-			if (wChannels>16)
-			{
-			    st_fail_errno(ft,ST_EOF,"Channels(%d) must be <= 16\n",wChannels);
-			    return ST_EOF;
-			}
-			wFormatTag = WAVE_FORMAT_IMA_ADPCM;
-			wBlockAlign = wChannels * 256; /* reasonable default */
-			wBitsPerSample = 4;
-	    		wExtSize = 2;
-			wSamplesPerBlock = ImaSamplesIn(0, wChannels, wBlockAlign, 0);
-			break;
-		case ST_ENCODING_ADPCM:
-			if (wChannels>16)
-			{
-			    st_fail_errno(ft,ST_EOF,"Channels(%d) must be <= 16\n",wChannels);
-			    return ST_EOF;
-			}
-			wFormatTag = WAVE_FORMAT_ADPCM;
-			wBlockAlign = wChannels * 128; /* reasonable default */
-			wBitsPerSample = 4;
-	    		wExtSize = 4+4*7;      /* Ext fmt data length */
-			wSamplesPerBlock = AdpcmSamplesIn(0, wChannels, wBlockAlign, 0);
-			break;
-		case ST_ENCODING_GSM:
-#ifdef HAVE_LIBGSM
-		    if (wChannels!=1)
-		    {
-			st_warn("Overriding GSM audio from %d channel to 1\n",wChannels);
-			wChannels = ft->info.channels = 1;
-		    }
-		    wFormatTag = WAVE_FORMAT_GSM610;
-		    /* wAvgBytesPerSec = 1625*(wSamplesPerSecond/8000.)+0.5; */
-		    wBlockAlign=65;
-		    wBitsPerSample=0;  /* not representable as int   */
-		    wExtSize=2;        /* length of format extension */
-		    wSamplesPerBlock = 320;
-#else
-		    st_fail_errno(ft,ST_EOF,"sorry, no GSM6.10 support, recompile sox with gsm library");
-		    return ST_EOF;
-#endif
-		    break;
-	}
-	wav->formatTag = wFormatTag;
-	wav->blockAlign = wBlockAlign;
-	wav->samplesPerBlock = wSamplesPerBlock;
-
-	if (!second_header) { 	/* adjust for blockAlign */
-	    blocksWritten = wDataLength/wBlockAlign;
-	    wDataLength = blocksWritten * wBlockAlign;
-	    wSamplesWritten = blocksWritten * wSamplesPerBlock;
-	} else { 	/* fixup with real length */
-	    wSamplesWritten = wav->numSamples;
-	    switch(wFormatTag)
-		{
-	    	case WAVE_FORMAT_ADPCM:
-	    	case WAVE_FORMAT_IMA_ADPCM:
-		    wDataLength = wav->dataLength;
-		    break;
-#ifdef HAVE_LIBGSM
-		case WAVE_FORMAT_GSM610:
-		    /* intentional case fallthrough! */
-#endif
-		default:
-		    wSamplesWritten /= wChannels; /* because how rawwrite()'s work */
-		    blocksWritten = (wSamplesWritten+wSamplesPerBlock-1)/wSamplesPerBlock;
-		    wDataLength = blocksWritten * wBlockAlign;
-		}
-	}
-
-#ifdef HAVE_LIBGSM
-	if (wFormatTag == WAVE_FORMAT_GSM610)
-	    wDataLength = (wDataLength+1) & ~1; /*round up to even */
-#endif
-
-	if (wFormatTag != WAVE_FORMAT_PCM)
-	    wFmtSize += 2+wExtSize; /* plus ExtData */
-
-	wRiffLength = 4 + (8+wFmtSize) + (8+wDataLength); 
-	if (wFormatTag != WAVE_FORMAT_PCM) /* PCM omits the "fact" chunk */
-	    wRiffLength += (8+wFactSize);
-	
-	/* wAvgBytesPerSec <-- this is BEFORE compression, isn't it? guess not. */
-	wAvgBytesPerSec = (double)wBlockAlign*ft->info.rate / (double)wSamplesPerBlock + 0.5;
-
-	/* figured out header info, so write it */
-	st_writes(ft, "RIFF");
-	st_writedw(ft, wRiffLength);
-	st_writes(ft, "WAVE");
-	st_writes(ft, "fmt ");
-	st_writedw(ft, wFmtSize);
-	st_writew(ft, wFormatTag);
-	st_writew(ft, wChannels);
-	st_writedw(ft, wSamplesPerSecond);
-	st_writedw(ft, wAvgBytesPerSec);
-	st_writew(ft, wBlockAlign);
-	st_writew(ft, wBitsPerSample); /* end info common to all fmts */
-
-	/* if not PCM, we need to write out wExtSize even if wExtSize=0 */
-	if (wFormatTag != WAVE_FORMAT_PCM)
-	    st_writew(ft,wExtSize);
-
-	switch (wFormatTag)
-	{
-	int i;
-	case WAVE_FORMAT_IMA_ADPCM:
-	    st_writew(ft, wSamplesPerBlock);
-	    break;
-	case WAVE_FORMAT_ADPCM:
-	    st_writew(ft, wSamplesPerBlock);
-	    st_writew(ft, 7); /* nCoefs */
-	    for (i=0; i<7; i++) {
-	      st_writew(ft, iCoef[i][0]);
-	      st_writew(ft, iCoef[i][1]);
+    switch (ft->info.size)
+    {
+	case ST_SIZE_BYTE:
+	    wBitsPerSample = 8;
+	    if (ft->info.encoding != ST_ENCODING_UNSIGNED &&
+		    ft->info.encoding != ST_ENCODING_ULAW &&
+		    ft->info.encoding != ST_ENCODING_ALAW &&
+		    ft->info.encoding != ST_ENCODING_GSM &&
+		    ft->info.encoding != ST_ENCODING_ADPCM &&
+		    ft->info.encoding != ST_ENCODING_IMA_ADPCM)
+	    {
+		st_warn("Do not support %s with 8-bit data.  Forcing to unsigned",st_encodings_str[(unsigned char)ft->info.encoding]);
+		ft->info.encoding = ST_ENCODING_UNSIGNED;
 	    }
 	    break;
-#ifdef HAVE_LIBGSM
-	case WAVE_FORMAT_GSM610:
-	    st_writew(ft, wSamplesPerBlock);
+	case ST_SIZE_WORD:
+	    wBitsPerSample = 16;
+	    if (ft->info.encoding != ST_ENCODING_SIGN2)
+	    {
+		st_warn("Do not support %s with 16-bit data.  Forcing to Signed.",st_encodings_str[(unsigned char)ft->info.encoding]);
+		ft->info.encoding = ST_ENCODING_SIGN2;
+	    }
 	    break;
+	case ST_SIZE_DWORD:
+	    wBitsPerSample = 32;
+	    if (ft->info.encoding != ST_ENCODING_SIGN2)
+	    {
+		st_warn("Do not support %s with 16-bit data.  Forcing to Signed.",st_encodings_str[(unsigned char)ft->info.encoding]);
+		ft->info.encoding = ST_ENCODING_SIGN2;
+	    }
+
+	    break;
+	default:
+	    st_warn("Do not support %s in WAV files.  Forcing to Signed Words.",st_sizes_str[(unsigned char)ft->info.size]);
+	    ft->info.encoding = ST_ENCODING_SIGN2;
+	    ft->info.size = ST_SIZE_WORD;
+	    wBitsPerSample = 16;
+	    break;
+    }
+
+    wSamplesPerBlock = 1;	/* common default for PCM data */
+
+    switch (ft->info.encoding)
+    {
+	case ST_ENCODING_UNSIGNED:
+	case ST_ENCODING_SIGN2:
+	    wFormatTag = WAVE_FORMAT_PCM;
+	    bytespersample = (wBitsPerSample + 7)/8;
+	    wBlockAlign = wChannels * bytespersample;
+	    break;
+	case ST_ENCODING_ALAW:
+	    wFormatTag = WAVE_FORMAT_ALAW;
+	    wBlockAlign = wChannels;
+	    break;
+	case ST_ENCODING_ULAW:
+	    wFormatTag = WAVE_FORMAT_MULAW;
+	    wBlockAlign = wChannels;
+	    break;
+	case ST_ENCODING_IMA_ADPCM:
+	    if (wChannels>16)
+	    {
+		st_fail_errno(ft,ST_EOF,"Channels(%d) must be <= 16\n",wChannels);
+		return ST_EOF;
+	    }
+	    wFormatTag = WAVE_FORMAT_IMA_ADPCM;
+	    wBlockAlign = wChannels * 256; /* reasonable default */
+	    wBitsPerSample = 4;
+	    wExtSize = 2;
+	    wSamplesPerBlock = ImaSamplesIn(0, wChannels, wBlockAlign, 0);
+	    break;
+	case ST_ENCODING_ADPCM:
+	    if (wChannels>16)
+	    {
+		st_fail_errno(ft,ST_EOF,"Channels(%d) must be <= 16\n",wChannels);
+		return ST_EOF;
+	    }
+	    wFormatTag = WAVE_FORMAT_ADPCM;
+	    wBlockAlign = wChannels * 128; /* reasonable default */
+	    wBitsPerSample = 4;
+	    wExtSize = 4+4*7;      /* Ext fmt data length */
+	    wSamplesPerBlock = AdpcmSamplesIn(0, wChannels, wBlockAlign, 0);
+	    break;
+	case ST_ENCODING_GSM:
+#ifdef ENABLE_GSM
+	    if (wChannels!=1)
+	    {
+		st_warn("Overriding GSM audio from %d channel to 1\n",wChannels);
+		wChannels = ft->info.channels = 1;
+	    }
+	    wFormatTag = WAVE_FORMAT_GSM610;
+	    /* dwAvgBytesPerSec = 1625*(dwSamplesPerSecond/8000.)+0.5; */
+	    wBlockAlign=65;
+	    wBitsPerSample=0;  /* not representable as int   */
+	    wExtSize=2;        /* length of format extension */
+	    wSamplesPerBlock = 320;
+#else
+	    st_fail_errno(ft,ST_EOF,"sorry, no GSM6.10 support, recompile sox with gsm library");
+	    return ST_EOF;
+#endif
+	    break;
+    }
+    wav->formatTag = wFormatTag;
+    wav->blockAlign = wBlockAlign;
+    wav->samplesPerBlock = wSamplesPerBlock;
+
+    if (!second_header) { 	/* adjust for blockAlign */
+	blocksWritten = dwDataLength/wBlockAlign;
+	dwDataLength = blocksWritten * wBlockAlign;
+	dwSamplesWritten = blocksWritten * wSamplesPerBlock;
+    } else { 	/* fixup with real length */
+	dwSamplesWritten = wav->numSamples;
+	switch(wFormatTag)
+	{
+	    case WAVE_FORMAT_ADPCM:
+	    case WAVE_FORMAT_IMA_ADPCM:
+		dwDataLength = wav->dataLength;
+		break;
+#ifdef ENABLE_GSM
+	    case WAVE_FORMAT_GSM610:
+		/* intentional case fallthrough! */
+#endif
+	    default:
+		dwSamplesWritten /= wChannels; /* because how rawwrite()'s work */
+		blocksWritten = (dwSamplesWritten+wSamplesPerBlock-1)/wSamplesPerBlock;
+		dwDataLength = blocksWritten * wBlockAlign;
+	}
+    }
+
+#ifdef ENABLE_GSM
+    if (wFormatTag == WAVE_FORMAT_GSM610)
+	dwDataLength = (dwDataLength+1) & ~1; /*round up to even */
+#endif
+
+    if (wFormatTag != WAVE_FORMAT_PCM)
+	wFmtSize += 2+wExtSize; /* plus ExtData */
+
+    wRiffLength = 4 + (8+wFmtSize) + (8+dwDataLength); 
+    if (wFormatTag != WAVE_FORMAT_PCM) /* PCM omits the "fact" chunk */
+	wRiffLength += (8+dwFactSize);
+
+    /* dwAvgBytesPerSec <-- this is BEFORE compression, isn't it? guess not. */
+    dwAvgBytesPerSec = (double)wBlockAlign*ft->info.rate / (double)wSamplesPerBlock + 0.5;
+
+    /* figured out header info, so write it */
+    st_writes(ft, "RIFF");
+    st_writedw(ft, wRiffLength);
+    st_writes(ft, "WAVE");
+    st_writes(ft, "fmt ");
+    st_writedw(ft, wFmtSize);
+    st_writew(ft, wFormatTag);
+    st_writew(ft, wChannels);
+    st_writedw(ft, dwSamplesPerSecond);
+    st_writedw(ft, dwAvgBytesPerSec);
+    st_writew(ft, wBlockAlign);
+    st_writew(ft, wBitsPerSample); /* end info common to all fmts */
+
+    /* if not PCM, we need to write out wExtSize even if wExtSize=0 */
+    if (wFormatTag != WAVE_FORMAT_PCM)
+	st_writew(ft,wExtSize);
+
+    switch (wFormatTag)
+    {
+	int i;
+	case WAVE_FORMAT_IMA_ADPCM:
+	st_writew(ft, wSamplesPerBlock);
+	break;
+	case WAVE_FORMAT_ADPCM:
+	st_writew(ft, wSamplesPerBlock);
+	st_writew(ft, 7); /* nCoefs */
+	for (i=0; i<7; i++) {
+	    st_writew(ft, iCoef[i][0]);
+	    st_writew(ft, iCoef[i][1]);
+	}
+	break;
+#ifdef ENABLE_GSM
+	case WAVE_FORMAT_GSM610:
+	st_writew(ft, wSamplesPerBlock);
+	break;
 #endif
 	default:
-	    break;
+	break;
+    }
+
+    /* if not PCM, write the 'fact' chunk */
+    if (wFormatTag != WAVE_FORMAT_PCM){
+	st_writes(ft, "fact");
+	st_writedw(ft,dwFactSize); 
+	st_writedw(ft,dwSamplesWritten);
+    }
+
+    st_writes(ft, "data");
+    st_writedw(ft, dwDataLength);		/* data chunk size */
+
+    if (!second_header) {
+	st_report("Writing Wave file: %s format, %d channel%s, %d samp/sec",
+		wav_format_str(wFormatTag), wChannels,
+		wChannels == 1 ? "" : "s", dwSamplesPerSecond);
+	st_report("        %d byte/sec, %d block align, %d bits/samp",
+		dwAvgBytesPerSec, wBlockAlign, wBitsPerSample);
+    } else {
+	st_report("Finished writing Wave file, %u data bytes %u samples\n",
+		dwDataLength,wav->numSamples);
+#ifdef ENABLE_GSM
+	if (wFormatTag == WAVE_FORMAT_GSM610){
+	    st_report("GSM6.10 format: %u blocks %u padded samples %u padded data bytes\n",
+		    blocksWritten, dwSamplesWritten, dwDataLength);
+	    if (wav->gsmbytecount != dwDataLength)
+		st_warn("help ! internal inconsistency - data_written %u gsmbytecount %u",
+			dwDataLength, wav->gsmbytecount);
+
 	}
-
-	/* if not PCM, write the 'fact' chunk */
-	if (wFormatTag != WAVE_FORMAT_PCM){
-	    st_writes(ft, "fact");
-	    st_writedw(ft,wFactSize); 
-	    st_writedw(ft,wSamplesWritten);
-	}
-
-	st_writes(ft, "data");
-	st_writedw(ft, wDataLength);		/* data chunk size */
-
-	if (!second_header) {
-		st_report("Writing Wave file: %s format, %d channel%s, %d samp/sec",
-	        	wav_format_str(wFormatTag), wChannels,
-	        	wChannels == 1 ? "" : "s", wSamplesPerSecond);
-		st_report("        %d byte/sec, %d block align, %d bits/samp",
-	                wAvgBytesPerSec, wBlockAlign, wBitsPerSample);
-	} else {
-		st_report("Finished writing Wave file, %u data bytes %u samples\n",
-			wDataLength,wav->numSamples);
-#ifdef HAVE_LIBGSM
-		if (wFormatTag == WAVE_FORMAT_GSM610){
-		    st_report("GSM6.10 format: %u blocks %u padded samples %u padded data bytes\n",
-			blocksWritten, wSamplesWritten, wDataLength);
-		    if (wav->gsmbytecount != wDataLength)
-			st_warn("help ! internal inconsistency - data_written %u gsmbytecount %u",
-				wDataLength, wav->gsmbytecount);
-
-		}
 #endif
-	}
-	return ST_SUCCESS;
+    }
+    return ST_SUCCESS;
 }
 
-LONG st_wavwrite(ft, buf, len) 
-ft_t ft;
-LONG *buf, len;
+st_ssize_t st_wavwrite(ft_t ft, st_sample_t *buf, st_ssize_t len) 
 {
 	wav_t	wav = (wav_t) ft->priv;
-	LONG	total_len = len;
+	st_ssize_t total_len = len;
 
 	ft->st_errno = ST_SUCCESS;
 
@@ -1529,7 +1499,7 @@ LONG *buf, len;
 	    return total_len - len;
 	    break;
 
-#ifdef HAVE_LIBGSM
+#ifdef ENABLE_GSM
 	case WAVE_FORMAT_GSM610:
 	    len = wavgsmwrite(ft, buf, len);
 	    wav->numSamples += len;
@@ -1543,8 +1513,7 @@ LONG *buf, len;
 	}
 }
 
-int st_wavstopwrite(ft) 
-ft_t ft;
+int st_wavstopwrite(ft_t ft) 
 {
 	wav_t	wav = (wav_t) ft->priv;
 
@@ -1558,7 +1527,7 @@ ft_t ft;
 	case WAVE_FORMAT_ADPCM:
 	    xxxAdpcmWriteBlock(ft);
 	    break;
-#ifdef HAVE_LIBGSM
+#ifdef ENABLE_GSM
 	case WAVE_FORMAT_GSM610:
 	    wavgsmstopwrite(ft);
 	    break;
@@ -1594,9 +1563,7 @@ ft_t ft;
 /*
  * Return a string corresponding to the wave format type.
  */
-static char *
-wav_format_str(wFormatTag) 
-unsigned wFormatTag;
+static char *wav_format_str(unsigned wFormatTag) 
 {
 	switch (wFormatTag)
 	{
@@ -1645,9 +1612,7 @@ unsigned wFormatTag;
 	}
 }
 
-int st_wavseek(ft,offset) 
-ft_t ft;
-LONG offset;
+int st_wavseek(ft_t ft, st_size_t offset) 
 {
 	wav_t	wav = (wav_t) ft->priv;
 
@@ -1655,7 +1620,7 @@ LONG offset;
 	{
 	case WAVE_FORMAT_IMA_ADPCM:
 	case WAVE_FORMAT_ADPCM:
-#ifdef HAVE_LIBGSM
+#ifdef ENABLE_GSM
 	case WAVE_FORMAT_GSM610:
 #endif
 		st_fail_errno(ft,ST_ENOTSUP,"Only PCM Supported");
